type token =
  | IDENT of (string * Cabs.cabsloc)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string * Cabs.cabsloc)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | INT32 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | ATTRIBUTE_USED of (Cabs.cabsloc)
  | BUILTIN_VA_LIST
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_EOL
  | AT_TRANSFORM of (Cabs.cabsloc)
  | AT_TRANSFORMEXPR of (Cabs.cabsloc)
  | AT_SPECIFIER of (Cabs.cabsloc)
  | AT_EXPR of (Cabs.cabsloc)
  | AT_NAME

open Parsing;;
# 44 "src/frontc/cparser.mly"
open Cabs
module E = Errormsg

let parse_error msg : unit =       (* sm: c++-mode highlight hack: -> ' <- *)
  E.parse_error msg

let print = print_string

(* unit -> string option *)
(*
let getComments () =
  match !comments with
    [] -> None
  | _ -> 
      let r = Some(String.concat "\n" (List.rev !comments)) in
      comments := [];
      r
*)

let currentLoc () = 
  let l, f, c = E.getPosition () in
  { lineno   = l; 
    filename = f; 
    byteno   = c;}

let cabslu = {lineno = -10; 
	      filename = "cabs loc unknown"; 
	      byteno = -10;}

(* cabsloc -> cabsloc *)
(*
let handleLoc l =
  l.clcomment <- getComments();
  l
*)

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> NOTHING
  | [expr] -> expr
  | _ -> COMMA (lst)


let currentFunctionName = ref "<outside any function>"
    
let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body. 
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (* Go through all the parameter names and mark them as identifiers *)
  let rec findProto = function
      PROTO (d, args, _) when isJUSTBASE d -> 
        List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args

    | PROTO (d, _, _) -> findProto d
    | PARENTYPE (_, d, _) -> findProto d
    | PTR (_, d) -> findProto d
    | ARRAY (d, _, _) -> findProto d
    | _ -> parse_error "Cannot find the prototype in a function definition";
           raise Parsing.Parse_error 

  and isJUSTBASE = function
      JUSTBASE -> true
    | PARENTYPE (_, d, _) -> isJUSTBASE d
    | _ -> false
  in
  findProto decl;
  currentFunctionName := n



let applyPointer (ptspecs: attribute list list) (dt: decl_type)  
       : decl_type = 
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration (loc: cabsloc) (specs: spec_elem list) (nl: init_name list) : definition = 
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      DECDEF ((specs, nl), loc)  
    end


let doFunctionDef (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list) 
                  (n: name) 
                  (b: block) : definition = 
  let fname = (specs, n) in
  FUNDEF (fname, b, loc, lend)


let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool)) 
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let checkConnective (s : string) : unit =
begin
  (* checking this means I could possibly have more connectives, with *)
  (* different meaning *)
  if (s <> "to") then (
    parse_error "transformer connective must be 'to'";
    raise Parsing.Parse_error
  )
  else ()
end

let int64_to_char value =
  if (compare value (Int64.of_int 255) > 0) || (compare value Int64.zero < 0) then
    begin
      let msg = Printf.sprintf "cparser:intlist_to_string: character 0x%Lx too big" value in
      parse_error msg;
      raise Parsing.Parse_error
    end
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let rec intlist_to_string (str: int64 list):string =
  match str with
    [] -> ""  (* add nul-termination *)
  | value::rest ->
      let this_char = int64_to_char value in
      (String.make 1 this_char) ^ (intlist_to_string rest)

let fst3 (result, _, _) = result
let snd3 (_, result, _) = result
let trd3 (_, _, result) = result


(*
   transform:  __builtin_offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let transformOffsetOf (speclist, dtype) member =
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, variadic) ->
	PROTO (addPointer dtype, names, variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = CONSTANT (CONST_INT "0") in
  let castExpr = CAST (nullType, SINGLE_INIT nullExpr) in

  let rec replaceBase = function
    | VARIABLE field ->
	MEMBEROFPTR (castExpr, field)
    | MEMBEROF (base, field) ->
	MEMBEROF (replaceBase base, field)
    | INDEX (base, index) ->
	INDEX (replaceBase base, index)
    | _ ->
	parse_error "malformed offset expression in __builtin_offsetof";
        raise Parsing.Parse_error 
  in
  let memberExpr = replaceBase member in
  let addrExpr = UNARY (ADDROF, memberExpr) in
  (* slight cheat: hard-coded assumption that size_t == unsigned int *)
  let sizeofType = [SpecType Tunsigned], JUSTBASE in
  let resultExpr = CAST (sizeofType, SINGLE_INIT addrExpr) in
  resultExpr

# 327 "src/frontc/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  290 (* EQ *);
  291 (* PLUS_EQ *);
  292 (* MINUS_EQ *);
  293 (* STAR_EQ *);
  294 (* SLASH_EQ *);
  295 (* PERCENT_EQ *);
  296 (* AND_EQ *);
  297 (* PIPE_EQ *);
  298 (* CIRC_EQ *);
  299 (* INF_INF_EQ *);
  300 (* SUP_SUP_EQ *);
  301 (* ARROW *);
  302 (* DOT *);
  303 (* EQ_EQ *);
  304 (* EXCLAM_EQ *);
  305 (* INF *);
  306 (* SUP *);
  307 (* INF_EQ *);
  308 (* SUP_EQ *);
  312 (* SLASH *);
  313 (* PERCENT *);
  316 (* PIPE *);
  317 (* CIRC *);
  320 (* PIPE_PIPE *);
  321 (* INF_INF *);
  322 (* SUP_SUP *);
  325 (* RPAREN *);
  329 (* LBRACKET *);
  330 (* RBRACKET *);
  331 (* COLON *);
  333 (* COMMA *);
  334 (* ELLIPSIS *);
  335 (* QUEST *);
  350 (* ELSE *);
  357 (* LABEL__ *);
  360 (* BUILTIN_VA_LIST *);
  361 (* BLOCKATTRIBUTE *);
  369 (* PRAGMA_EOL *);
  374 (* AT_NAME *);
    0|]

let yytransl_block = [|
  257 (* IDENT *);
  258 (* CST_CHAR *);
  259 (* CST_WCHAR *);
  260 (* CST_INT *);
  261 (* CST_FLOAT *);
  262 (* NAMED_TYPE *);
  263 (* CST_STRING *);
  264 (* CST_WSTRING *);
  265 (* CHAR *);
  266 (* INT *);
  267 (* DOUBLE *);
  268 (* FLOAT *);
  269 (* VOID *);
  270 (* INT64 *);
  271 (* INT32 *);
  272 (* ENUM *);
  273 (* STRUCT *);
  274 (* TYPEDEF *);
  275 (* UNION *);
  276 (* SIGNED *);
  277 (* UNSIGNED *);
  278 (* LONG *);
  279 (* SHORT *);
  280 (* VOLATILE *);
  281 (* EXTERN *);
  282 (* STATIC *);
  283 (* CONST *);
  284 (* RESTRICT *);
  285 (* AUTO *);
  286 (* REGISTER *);
  287 (* THREAD *);
  288 (* SIZEOF *);
  289 (* ALIGNOF *);
  309 (* PLUS *);
  310 (* MINUS *);
  311 (* STAR *);
  314 (* TILDE *);
  315 (* AND *);
  318 (* EXCLAM *);
  319 (* AND_AND *);
  323 (* PLUS_PLUS *);
  324 (* MINUS_MINUS *);
  326 (* LPAREN *);
  327 (* RBRACE *);
  328 (* LBRACE *);
  332 (* SEMICOLON *);
  336 (* BREAK *);
  337 (* CONTINUE *);
  338 (* GOTO *);
  339 (* RETURN *);
  340 (* SWITCH *);
  341 (* CASE *);
  342 (* DEFAULT *);
  343 (* WHILE *);
  344 (* DO *);
  345 (* FOR *);
  346 (* IF *);
  347 (* TRY *);
  348 (* EXCEPT *);
  349 (* FINALLY *);
  351 (* ATTRIBUTE *);
  352 (* INLINE *);
  353 (* ASM *);
  354 (* TYPEOF *);
  355 (* FUNCTION__ *);
  356 (* PRETTY_FUNCTION__ *);
  358 (* BUILTIN_VA_ARG *);
  359 (* ATTRIBUTE_USED *);
  362 (* BUILTIN_TYPES_COMPAT *);
  363 (* BUILTIN_OFFSETOF *);
  364 (* DECLSPEC *);
  365 (* MSASM *);
  366 (* MSATTR *);
  367 (* PRAGMA_LINE *);
  368 (* PRAGMA *);
  370 (* AT_TRANSFORM *);
  371 (* AT_TRANSFORMEXPR *);
  372 (* AT_SPECIFIER *);
  373 (* AT_EXPR *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\051\000\004\000\004\000\
\004\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\055\000\055\000\055\000\056\000\056\000\057\000\057\000\
\057\000\057\000\057\000\058\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\059\000\059\000\
\059\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\062\000\
\062\000\063\000\063\000\063\000\063\000\064\000\064\000\064\000\
\065\000\065\000\065\000\066\000\066\000\066\000\066\000\066\000\
\067\000\067\000\067\000\068\000\068\000\069\000\069\000\070\000\
\070\000\071\000\071\000\072\000\072\000\073\000\073\000\074\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\011\000\009\000\009\000\009\000\009\000\
\009\000\009\000\010\000\075\000\018\000\018\000\019\000\019\000\
\019\000\076\000\076\000\076\000\013\000\013\000\021\000\021\000\
\060\000\060\000\020\000\020\000\020\000\077\000\077\000\022\000\
\022\000\022\000\023\000\023\000\078\000\016\000\016\000\012\000\
\012\000\014\000\014\000\014\000\079\000\079\000\015\000\015\000\
\017\000\017\000\035\000\035\000\080\000\081\000\081\000\036\000\
\036\000\036\000\036\000\036\000\037\000\037\000\038\000\038\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\008\000\008\000\008\000\008\000\008\000\008\000\008\000\008\000\
\083\000\083\000\031\000\031\000\041\000\041\000\040\000\040\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\086\000\086\000\087\000\087\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\026\000\026\000\026\000\026\000\026\000\
\026\000\044\000\044\000\043\000\043\000\043\000\030\000\030\000\
\030\000\029\000\029\000\042\000\045\000\045\000\045\000\045\000\
\045\000\090\000\091\000\091\000\092\000\092\000\092\000\028\000\
\028\000\028\000\028\000\027\000\093\000\093\000\039\000\039\000\
\054\000\054\000\054\000\094\000\094\000\094\000\049\000\050\000\
\050\000\034\000\034\000\048\000\048\000\046\000\046\000\046\000\
\046\000\047\000\047\000\032\000\033\000\033\000\033\000\033\000\
\033\000\052\000\052\000\052\000\005\000\005\000\006\000\006\000\
\006\000\088\000\088\000\088\000\088\000\095\000\095\000\095\000\
\095\000\096\000\096\000\089\000\089\000\053\000\053\000\053\000\
\098\000\098\000\098\000\098\000\098\000\098\000\098\000\098\000\
\098\000\098\000\098\000\099\000\099\000\099\000\099\000\099\000\
\100\000\100\000\100\000\100\000\100\000\100\000\100\000\100\000\
\100\000\100\000\100\000\101\000\102\000\102\000\102\000\102\000\
\103\000\103\000\103\000\104\000\104\000\104\000\105\000\105\000\
\105\000\105\000\105\000\106\000\106\000\106\000\107\000\107\000\
\108\000\108\000\109\000\109\000\110\000\110\000\111\000\111\000\
\097\000\112\000\112\000\112\000\082\000\082\000\007\000\007\000\
\007\000\084\000\084\000\085\000\085\000\113\000\113\000\115\000\
\115\000\116\000\116\000\114\000\114\000\117\000\117\000\118\000\
\118\000\000\000\000\000"

let yylen = "\002\000\
\002\000\001\000\000\000\002\000\002\000\000\000\001\000\001\000\
\003\000\005\000\005\000\001\000\006\000\004\000\008\000\008\000\
\003\000\001\000\001\000\004\000\000\000\001\000\001\000\001\000\
\001\000\003\000\004\000\001\000\002\000\004\000\006\000\006\000\
\006\000\003\000\003\000\002\000\002\000\006\000\001\000\003\000\
\002\000\001\000\002\000\002\000\002\000\004\000\002\000\004\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\001\000\
\004\000\001\000\003\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\003\000\001\000\003\000\003\000\003\000\003\000\
\001\000\003\000\003\000\001\000\003\000\001\000\003\000\001\000\
\003\000\001\000\003\000\001\000\003\000\001\000\005\000\001\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\001\000\002\000\
\002\000\001\000\001\000\001\000\001\000\003\000\001\000\003\000\
\000\000\001\000\003\000\002\000\001\000\001\000\000\000\003\000\
\004\000\005\000\000\000\001\000\002\000\000\000\001\000\000\000\
\001\000\001\000\003\000\003\000\000\000\001\000\003\000\003\000\
\003\000\003\000\005\000\003\000\001\000\000\000\002\000\000\000\
\002\000\002\000\002\000\002\000\000\000\004\000\001\000\003\000\
\001\000\002\000\001\000\003\000\005\000\003\000\003\000\005\000\
\008\000\003\000\004\000\006\000\002\000\002\000\003\000\002\000\
\002\000\003\000\004\000\007\000\001\000\005\000\004\000\003\000\
\002\000\001\000\003\000\002\000\001\000\003\000\001\000\003\000\
\002\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\002\000\004\000\000\000\001\000\000\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\002\000\003\000\005\000\004\000\006\000\005\000\002\000\005\000\
\004\000\006\000\005\000\002\000\006\000\005\000\007\000\006\000\
\001\000\004\000\004\000\000\000\003\000\002\000\004\000\002\000\
\003\000\001\000\003\000\001\000\003\000\002\000\001\000\003\000\
\003\000\001\000\003\000\003\000\001\000\004\000\005\000\005\000\
\004\000\001\000\000\000\002\000\000\000\002\000\003\000\002\000\
\002\000\001\000\003\000\002\000\005\000\003\000\001\000\003\000\
\000\000\004\000\004\000\001\000\003\000\001\000\003\000\000\000\
\001\000\002\000\001\000\003\000\001\000\004\000\003\000\004\000\
\004\000\001\000\000\000\002\000\002\000\002\000\004\000\005\000\
\003\000\001\000\001\000\001\000\000\000\002\000\000\000\002\000\
\005\000\004\000\002\000\001\000\001\000\001\000\001\000\001\000\
\001\000\004\000\002\000\001\000\002\000\003\000\004\000\001\000\
\001\000\001\000\003\000\002\000\001\000\001\000\001\000\003\000\
\003\000\003\000\001\000\001\000\003\000\002\000\003\000\003\000\
\001\000\002\000\004\000\002\000\004\000\002\000\002\000\002\000\
\002\000\002\000\002\000\001\000\001\000\003\000\003\000\003\000\
\001\000\003\000\003\000\001\000\003\000\003\000\001\000\003\000\
\003\000\003\000\003\000\001\000\003\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\003\000\
\001\000\001\000\003\000\003\000\003\000\003\000\000\000\002\000\
\002\000\001\000\002\000\000\000\003\000\000\000\001\000\001\000\
\003\000\004\000\004\000\000\000\003\000\000\000\002\000\001\000\
\003\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\233\000\208\000\210\000\214\000\
\213\000\207\000\212\000\000\000\000\000\000\000\000\000\215\000\
\216\000\211\000\209\000\043\001\000\000\000\000\042\001\044\001\
\000\000\000\000\053\001\000\000\000\000\000\000\000\000\000\000\
\000\000\052\001\064\001\000\000\000\000\000\000\000\000\146\001\
\000\000\002\000\000\000\000\000\000\000\007\000\008\000\000\000\
\000\000\000\000\012\000\000\000\147\001\000\000\000\000\018\000\
\019\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\204\000\193\000\000\000\000\000\
\000\000\114\000\115\000\116\000\000\000\000\000\109\000\194\000\
\195\000\196\000\197\000\005\000\000\000\199\000\000\000\000\000\
\000\000\051\001\000\000\000\000\066\001\075\001\071\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\070\001\000\000\076\001\000\000\092\001\093\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\001\000\004\000\000\000\188\000\
\038\001\000\000\000\000\000\000\025\001\000\000\206\000\198\000\
\006\000\149\000\036\001\000\000\000\000\200\000\201\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\247\000\
\000\000\000\000\059\001\000\000\000\000\000\000\000\000\061\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\009\000\110\000\
\000\000\000\000\023\000\103\000\104\000\101\000\102\000\111\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\024\000\105\000\000\000\025\000\000\000\000\000\000\000\028\000\
\000\000\056\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\088\000\100\000\000\000\
\000\000\000\000\068\001\000\000\000\000\078\001\000\000\000\000\
\082\001\000\000\084\001\086\001\087\001\088\001\091\001\089\001\
\090\001\000\000\000\000\000\000\062\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\057\001\055\001\056\001\000\000\
\054\001\000\000\000\000\187\000\000\000\000\000\000\000\253\000\
\012\001\000\000\000\000\000\000\017\000\000\000\014\000\000\000\
\000\000\008\001\009\001\000\000\000\000\000\000\004\001\039\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\238\000\000\000\000\000\000\000\000\000\000\000\000\000\
\220\000\240\000\000\000\000\000\000\000\225\000\000\000\000\000\
\000\000\000\000\000\000\050\001\000\000\000\000\045\000\000\000\
\047\000\049\000\050\000\051\000\054\000\052\000\053\000\055\000\
\000\000\043\000\044\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\234\000\113\000\112\000\026\001\
\000\000\235\000\000\000\000\000\036\000\037\000\000\000\000\000\
\029\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\126\001\
\000\000\000\000\125\001\077\001\072\001\073\001\000\000\000\000\
\067\001\074\001\063\001\079\001\080\001\094\001\095\001\096\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\202\000\023\001\046\001\190\000\000\000\117\000\192\000\
\000\000\000\000\000\000\000\000\252\000\000\000\000\000\148\000\
\000\000\000\000\000\000\000\000\016\001\000\000\000\000\011\001\
\000\000\000\000\000\000\000\000\006\001\000\000\251\000\249\000\
\248\000\230\000\058\001\020\000\000\000\000\000\000\000\241\000\
\246\000\237\000\000\000\000\000\000\000\219\000\222\000\000\000\
\224\000\227\000\000\000\010\000\011\000\000\000\000\000\000\000\
\144\000\000\000\000\000\143\000\000\000\026\000\000\000\000\000\
\000\000\000\000\000\000\035\000\034\000\000\000\135\000\000\000\
\000\000\000\000\089\000\090\000\091\000\092\000\093\000\094\000\
\095\000\096\000\097\000\098\000\099\000\059\000\060\000\061\000\
\058\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\137\000\000\000\124\001\123\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\125\000\000\000\122\000\000\000\
\000\000\000\000\000\000\000\000\014\001\000\000\000\000\000\000\
\000\000\048\001\000\000\000\000\151\000\000\000\000\000\161\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\181\000\000\000\000\000\
\000\000\163\000\000\000\000\000\022\001\000\000\000\000\013\000\
\000\000\000\000\002\001\028\001\000\000\000\000\007\001\229\000\
\232\000\000\000\245\000\243\000\239\000\221\000\226\000\000\000\
\000\000\000\000\140\000\139\000\000\000\057\000\000\000\000\000\
\000\000\027\000\000\000\030\000\146\000\145\000\000\000\000\000\
\000\000\000\000\000\000\000\000\126\000\000\000\133\000\118\000\
\124\000\254\000\000\000\000\000\142\000\000\000\000\000\001\001\
\160\000\158\000\000\000\000\000\176\000\177\000\000\000\000\000\
\174\000\000\000\000\000\000\000\000\000\173\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\154\000\
\162\000\153\000\147\000\156\000\000\000\000\000\031\001\000\000\
\000\000\000\000\231\000\000\000\000\000\000\000\039\000\000\000\
\087\000\000\000\000\000\132\000\128\000\000\000\000\000\120\000\
\123\000\013\001\000\001\255\000\000\000\184\000\170\000\178\000\
\000\000\175\000\000\000\166\000\000\000\000\000\167\000\000\000\
\000\000\000\000\186\000\000\000\000\000\000\000\000\000\128\001\
\129\001\000\000\021\001\018\001\019\001\030\001\033\001\032\001\
\038\000\031\000\032\000\000\000\033\000\041\000\015\000\016\000\
\129\000\000\000\049\001\179\000\171\000\000\000\000\000\185\000\
\000\000\000\000\000\000\183\000\108\000\000\000\000\000\040\000\
\130\000\000\000\168\000\000\000\165\000\182\000\131\001\000\000\
\000\000\172\000\000\000\000\000\000\000\000\000\136\001\000\000\
\000\000\000\000\000\000\133\001\000\000\180\000\169\000\000\000\
\000\000\000\000\137\001\139\001\138\001\000\000\141\001\000\000\
\143\001\000\000\145\001"

let yydgoto = "\003\000\
\040\000\041\000\042\000\043\000\016\001\181\001\143\002\063\002\
\201\000\202\000\085\001\017\002\029\002\064\002\204\000\240\001\
\105\001\078\000\205\000\030\002\031\002\032\002\165\002\163\000\
\045\000\164\000\129\000\149\000\152\000\153\000\046\000\047\000\
\048\000\207\000\066\002\067\002\028\001\186\001\146\000\130\000\
\131\000\053\001\054\001\055\001\194\001\195\001\196\001\152\002\
\133\000\056\001\049\000\050\000\165\000\191\001\024\001\043\001\
\208\000\209\000\160\002\034\002\210\000\211\000\212\000\213\000\
\214\000\215\000\216\000\217\000\218\000\219\000\220\000\221\000\
\222\000\223\000\222\002\079\000\110\002\035\002\118\002\140\000\
\188\001\090\000\188\002\223\002\233\002\080\000\136\000\052\000\
\063\000\182\001\150\000\039\001\025\001\071\002\018\001\064\000\
\225\000\108\000\109\000\110\000\111\000\112\000\113\000\114\000\
\115\000\116\000\117\000\118\000\119\000\120\000\121\000\226\000\
\237\002\244\002\238\002\239\002\255\002\001\003"

let yysindex = "\068\001\
\121\012\121\012\000\000\237\254\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\066\255\154\255\187\014\092\000\000\000\
\000\000\000\000\000\000\000\000\115\013\187\014\000\000\000\000\
\187\014\187\014\000\000\121\012\255\254\187\014\027\255\045\255\
\102\255\000\000\000\000\046\007\107\255\208\255\205\255\000\000\
\033\001\000\000\121\012\016\255\210\014\000\000\000\000\032\255\
\049\000\187\014\000\000\187\014\000\000\057\000\024\014\000\000\
\000\000\114\000\012\000\102\255\071\000\093\000\097\255\214\255\
\188\009\097\000\101\255\187\014\000\000\000\000\188\009\104\000\
\139\255\000\000\000\000\000\000\051\014\216\255\000\000\000\000\
\000\000\000\000\000\000\000\000\102\255\000\000\216\255\079\009\
\001\015\000\000\047\255\105\000\000\000\000\000\000\000\024\011\
\095\011\046\007\046\007\046\007\046\007\046\007\046\007\046\007\
\109\000\000\000\229\254\000\000\182\000\000\000\000\000\204\000\
\162\000\243\000\049\001\002\001\127\000\095\000\141\000\142\000\
\145\000\152\012\114\011\235\000\000\000\000\000\206\000\000\000\
\000\000\178\000\171\000\232\000\000\000\195\255\000\000\000\000\
\000\000\000\000\000\000\167\000\202\000\000\000\000\000\216\000\
\221\000\233\000\024\014\000\001\238\000\248\000\041\001\000\000\
\251\000\102\255\000\000\063\001\114\000\114\000\031\001\000\000\
\032\001\188\009\254\254\047\001\188\009\188\009\188\009\053\001\
\074\001\188\009\188\009\070\001\121\012\016\255\000\000\000\000\
\066\001\080\001\000\000\000\000\000\000\000\000\000\000\000\000\
\185\011\000\012\114\011\114\011\114\011\114\011\114\011\114\011\
\150\001\019\012\019\012\219\005\085\001\090\001\099\001\103\001\
\000\000\000\000\120\001\000\000\098\255\000\001\132\001\000\000\
\161\001\000\000\217\007\038\001\030\001\055\001\165\001\064\001\
\138\001\142\001\163\001\147\001\012\255\000\000\000\000\062\255\
\153\001\158\001\000\000\126\001\235\001\000\000\243\001\219\005\
\000\000\219\005\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\186\001\012\002\179\001\000\000\053\255\053\255\046\007\
\046\007\046\007\046\007\046\007\046\007\046\007\046\007\046\007\
\046\007\046\007\046\007\046\007\046\007\046\007\046\007\046\007\
\046\007\223\001\233\001\245\001\000\000\000\000\000\000\000\001\
\000\000\206\000\000\001\000\000\064\010\206\000\226\000\000\000\
\000\000\251\001\055\002\218\001\000\000\057\000\000\000\187\014\
\255\001\000\000\000\000\000\000\250\255\142\013\000\000\000\000\
\114\011\123\001\254\001\001\002\002\002\251\000\251\000\114\000\
\188\009\000\000\114\011\188\009\253\001\004\002\000\002\195\255\
\000\000\000\000\013\002\015\002\188\009\000\000\016\002\017\002\
\188\009\018\002\232\000\000\000\009\002\219\005\000\000\219\005\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\219\005\000\000\000\000\144\255\020\002\024\002\029\002\034\002\
\114\011\187\014\187\014\109\002\000\000\000\000\000\000\000\000\
\058\002\000\000\053\255\053\255\000\000\000\000\242\007\057\008\
\000\000\114\011\114\011\114\011\114\011\114\011\114\011\114\011\
\114\011\114\011\114\011\114\011\114\011\114\011\114\011\114\011\
\114\011\114\011\114\011\114\011\114\011\114\011\114\011\114\011\
\114\011\114\011\114\011\114\011\114\011\114\011\242\007\000\000\
\072\015\072\015\000\000\000\000\000\000\000\000\072\002\082\002\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\204\000\204\000\162\000\162\000\243\000\243\000\243\000\243\000\
\049\001\049\001\002\001\127\000\095\000\141\000\142\000\153\002\
\154\002\000\000\000\000\000\000\000\000\013\007\000\000\000\000\
\000\001\057\000\206\000\088\002\000\000\024\014\007\001\000\000\
\085\002\087\002\102\255\101\005\000\000\030\255\090\002\000\000\
\190\000\046\001\082\001\094\002\000\000\238\000\000\000\000\000\
\000\000\000\000\000\000\000\000\098\002\102\002\251\000\000\000\
\000\000\000\000\114\011\020\255\188\009\000\000\000\000\103\002\
\000\000\000\000\104\002\000\000\000\000\107\002\108\002\110\002\
\000\000\242\007\242\007\000\000\136\010\000\000\101\002\105\002\
\115\002\111\002\190\000\000\000\000\000\118\002\000\000\128\002\
\173\255\113\002\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\038\001\038\001\030\001\030\001\055\001\055\001\055\001\
\055\001\165\001\165\001\064\001\138\001\142\001\163\001\147\001\
\123\002\000\000\122\002\000\000\000\000\112\002\112\002\132\002\
\136\002\000\000\053\255\114\011\000\000\133\002\000\000\166\002\
\134\002\143\002\064\010\152\002\000\000\170\002\076\008\216\255\
\177\002\000\000\055\002\167\000\000\000\118\002\172\002\000\000\
\173\002\174\002\055\255\089\007\178\002\114\011\176\002\178\002\
\152\006\185\002\178\002\032\255\121\000\000\000\101\005\182\002\
\101\005\000\000\189\002\101\005\000\000\186\002\188\002\000\000\
\196\002\000\001\000\000\000\000\024\014\242\007\000\000\000\000\
\000\000\195\002\000\000\000\000\000\000\000\000\000\000\112\002\
\112\002\112\002\000\000\000\000\013\007\000\000\187\014\187\014\
\010\003\000\000\000\001\000\000\000\000\000\000\114\011\121\012\
\114\011\245\254\044\000\013\007\000\000\064\010\000\000\000\000\
\000\000\000\000\187\014\081\000\000\000\199\002\205\002\000\000\
\000\000\000\000\091\000\152\006\000\000\000\000\202\002\242\007\
\000\000\204\002\147\008\152\006\170\000\000\000\152\006\211\002\
\200\002\081\006\152\006\072\001\121\000\121\000\218\002\000\000\
\000\000\000\000\000\000\000\000\030\255\079\014\000\000\220\002\
\221\002\217\002\000\000\225\002\223\002\230\002\000\000\227\255\
\000\000\229\002\236\002\000\000\000\000\245\254\114\011\000\000\
\000\000\000\000\000\000\000\000\206\000\000\000\000\000\000\000\
\239\002\000\000\144\255\000\000\152\006\114\011\000\000\152\006\
\178\002\243\002\000\000\242\007\226\002\178\002\032\255\000\000\
\000\000\062\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\075\003\000\000\000\000\000\000\000\000\
\000\000\032\003\000\000\000\000\000\000\035\003\039\003\000\000\
\042\003\152\006\032\255\000\000\000\000\062\003\044\003\000\000\
\000\000\152\006\000\000\242\007\000\000\000\000\000\000\216\255\
\051\003\000\000\052\003\053\003\047\003\049\003\000\000\056\003\
\152\006\218\008\216\255\000\000\216\255\000\000\000\000\058\003\
\059\003\054\003\000\000\000\000\000\000\062\003\000\000\074\003\
\000\000\062\003\000\000"

let yyrindex = "\000\000\
\013\000\014\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\084\000\000\000\000\000\
\000\000\000\000\000\000\000\000\038\255\084\000\000\000\000\000\
\084\000\084\000\000\000\010\000\000\000\084\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\010\000\207\000\031\000\000\000\000\000\000\000\
\000\000\084\000\000\000\084\000\000\000\172\013\064\003\000\000\
\000\000\000\000\000\000\000\000\000\000\240\001\000\000\145\255\
\068\003\095\002\000\000\084\000\000\000\000\000\068\003\206\002\
\000\000\000\000\000\000\000\000\000\000\007\013\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\048\003\107\009\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\083\002\000\000\000\000\121\016\
\144\012\193\002\128\003\242\001\125\002\208\002\149\006\234\255\
\122\001\135\003\000\000\000\000\000\000\000\000\055\000\000\000\
\000\000\078\003\000\000\212\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\003\004\000\000\000\000\000\000\086\003\
\057\255\000\000\000\000\074\000\093\003\000\000\122\255\000\000\
\099\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\068\003\207\000\000\000\068\003\068\003\068\003\061\003\
\000\000\068\003\068\003\000\000\040\255\207\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\139\015\101\001\000\000\000\000\
\185\015\000\000\243\016\114\017\213\017\252\008\198\009\234\002\
\089\003\164\008\221\006\094\006\222\001\000\000\000\000\000\000\
\109\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\108\000\
\000\000\140\003\207\000\000\000\000\000\046\255\128\001\000\000\
\000\000\000\000\000\000\121\004\000\000\000\000\000\000\225\255\
\000\000\000\000\000\000\134\000\107\003\000\000\000\000\000\000\
\000\000\110\003\000\000\000\000\000\000\099\003\099\003\000\000\
\068\003\000\000\000\000\068\003\091\001\106\003\000\000\000\000\
\000\000\000\000\000\000\000\000\068\003\000\000\000\000\000\000\
\068\003\000\000\106\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\112\003\198\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\107\003\000\000\000\000\000\000\000\000\000\000\115\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\111\003\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\155\016\188\016\088\015\211\016\247\003\109\004\227\004\089\005\
\207\005\069\006\014\002\161\003\132\006\217\006\194\000\000\000\
\000\000\000\000\000\000\000\000\000\000\114\003\000\000\000\000\
\207\000\172\013\166\007\000\000\000\000\064\003\252\255\000\000\
\120\003\000\000\000\000\119\003\000\000\207\000\142\255\000\000\
\165\000\071\001\054\000\000\000\000\000\093\003\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\099\003\000\000\
\000\000\000\000\000\000\207\000\068\003\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\222\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\147\017\180\017\246\017\023\018\056\018\089\018\122\018\
\155\018\185\013\180\018\233\005\161\009\010\010\138\007\108\007\
\000\000\000\000\000\000\000\000\000\000\054\016\088\016\000\000\
\000\000\035\017\000\000\000\000\000\000\129\003\000\000\208\010\
\000\000\000\000\000\000\000\000\000\000\000\000\127\003\000\000\
\000\000\000\000\000\000\003\004\000\000\153\000\081\017\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\136\003\000\000\119\003\000\000\
\119\003\000\000\000\000\119\003\000\000\171\000\000\000\000\000\
\000\000\192\000\000\000\000\000\064\003\127\003\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\231\015\
\021\016\000\000\000\000\000\000\114\003\000\000\000\000\000\000\
\000\000\000\000\222\000\000\000\000\000\000\000\000\000\040\255\
\000\000\248\009\000\000\114\003\000\000\000\000\000\000\000\000\
\000\000\000\000\246\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\147\003\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\081\017\
\000\000\143\003\000\000\000\000\136\003\136\003\000\000\000\000\
\000\000\000\000\000\000\000\000\207\000\225\255\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\248\009\000\000\000\000\
\000\000\000\000\000\000\000\000\062\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\143\003\239\004\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\019\000\142\003\000\000\
\000\000\000\000\000\000\151\003\000\000\000\000\000\000\027\000\
\000\000\000\000\000\000\000\000\154\003\036\000\000\000\000\000\
\000\000\000\000\027\000\000\000\000\000\000\000\000\000\000\000\
\000\000\157\003\000\000\000\000\000\000\000\000\000\000\158\003\
\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\226\004\237\255\107\004\023\255\050\003\045\000\167\254\
\000\000\235\255\171\255\155\253\243\254\204\255\005\254\000\000\
\071\002\000\000\000\000\000\000\000\000\179\253\066\002\098\000\
\000\000\038\000\000\000\127\255\192\003\141\255\181\255\000\000\
\000\000\087\255\209\255\196\254\191\002\201\002\248\254\000\000\
\217\003\229\255\000\000\031\003\111\004\000\000\000\000\168\255\
\120\255\238\255\126\255\000\000\003\000\196\253\021\000\230\254\
\000\000\000\000\000\000\098\254\037\001\156\001\088\001\110\001\
\115\000\109\001\118\003\121\003\117\003\122\003\116\003\000\000\
\148\002\178\007\140\254\203\255\000\000\000\000\175\002\000\000\
\000\000\215\255\000\000\032\002\000\000\131\003\000\000\140\255\
\240\000\002\000\090\254\095\003\000\000\151\002\000\255\000\000\
\248\255\000\000\000\000\000\000\034\000\247\001\054\002\219\001\
\241\001\251\003\039\004\040\004\038\004\044\004\000\000\183\001\
\061\002\000\000\000\000\060\002\000\000\057\002"

let yytablesize = 5123
let yytable = "\077\000\
\139\000\175\000\203\000\051\000\051\000\055\000\026\001\176\001\
\084\000\003\000\017\001\036\001\003\000\003\000\106\000\041\002\
\132\000\033\001\155\000\205\001\206\001\189\001\183\001\126\000\
\176\000\134\000\087\001\107\000\164\002\069\002\051\000\137\000\
\062\000\066\000\027\002\072\000\186\002\011\001\203\000\006\000\
\172\001\046\001\047\001\177\000\177\001\051\000\045\001\227\000\
\244\000\230\000\054\000\045\001\127\000\056\000\170\002\127\002\
\041\001\132\002\057\000\035\001\135\002\028\002\143\001\139\002\
\144\001\178\000\056\000\106\000\085\000\036\001\127\000\057\000\
\051\001\052\001\127\000\134\001\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\159\000\127\000\245\000\217\002\168\000\
\164\002\197\002\135\001\128\000\203\000\172\000\051\001\242\000\
\087\000\056\000\044\000\044\000\045\001\056\000\057\000\138\000\
\074\000\094\001\057\000\203\000\169\000\128\002\003\000\069\000\
\044\001\203\000\088\000\045\001\228\000\096\001\069\000\069\000\
\034\001\229\000\069\000\069\000\051\000\044\000\235\002\069\000\
\041\001\037\001\136\001\236\000\237\000\238\000\239\000\240\000\
\241\000\058\000\137\001\056\000\044\000\040\001\135\000\086\001\
\057\000\060\001\067\001\069\000\088\001\069\000\060\001\095\001\
\148\000\066\001\056\000\203\000\222\001\017\001\223\001\057\000\
\059\000\017\001\017\001\045\001\198\001\069\000\153\002\224\001\
\158\000\038\002\061\000\089\000\167\000\060\000\174\000\051\000\
\232\001\233\001\122\000\086\001\082\002\086\001\183\001\061\000\
\088\001\206\000\088\001\097\001\207\001\215\002\156\002\175\001\
\250\000\183\001\219\002\056\000\075\000\076\000\250\000\050\001\
\057\000\039\002\058\001\059\001\060\001\168\002\106\000\063\001\
\064\001\026\001\171\000\199\001\225\001\040\001\061\000\074\002\
\060\001\076\002\061\000\044\000\226\001\209\001\074\000\137\002\
\017\001\065\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\148\000\017\001\101\002\067\001\
\059\000\226\001\056\000\047\001\067\000\171\001\073\000\057\000\
\061\000\099\002\144\002\231\001\146\002\060\000\060\001\148\002\
\022\001\006\000\148\001\149\001\006\000\006\000\044\000\061\000\
\204\002\086\001\124\000\086\001\045\001\113\002\088\001\123\000\
\088\001\150\001\151\001\152\001\086\001\047\001\205\000\205\000\
\125\000\088\001\175\002\045\001\205\000\206\000\045\001\205\002\
\017\001\119\001\180\002\104\001\017\001\183\002\119\001\160\000\
\141\000\189\002\239\001\242\001\059\000\119\001\119\001\045\001\
\061\000\144\000\075\000\076\000\045\001\017\001\017\001\193\001\
\047\001\060\000\017\001\047\001\001\000\002\000\047\001\047\001\
\047\001\206\000\024\001\206\000\017\001\017\001\017\001\024\001\
\003\000\154\000\018\002\203\000\203\000\205\000\208\001\130\001\
\175\001\210\001\119\001\213\002\056\000\130\001\175\002\134\001\
\169\002\057\000\216\001\205\000\205\000\134\001\219\001\205\000\
\135\001\205\000\205\000\205\000\024\001\045\001\135\001\061\000\
\065\002\024\001\151\000\106\000\106\000\166\002\017\001\236\001\
\237\001\167\002\045\001\045\001\045\001\083\002\034\001\045\001\
\229\002\190\001\045\001\045\001\233\000\235\000\025\001\148\000\
\234\002\000\003\203\000\025\001\156\000\000\003\010\001\024\001\
\141\002\045\002\024\001\142\002\205\000\036\002\010\001\247\002\
\203\000\203\000\171\002\006\001\203\000\226\001\203\000\203\000\
\203\000\184\001\070\002\071\000\157\000\045\001\174\002\206\000\
\166\000\206\000\045\001\123\002\045\001\091\002\092\002\170\000\
\024\001\024\001\206\000\231\000\024\001\157\002\158\002\243\000\
\024\001\005\001\059\000\206\000\206\000\073\002\068\002\024\001\
\024\001\036\001\033\002\211\002\077\002\024\001\107\002\060\000\
\007\001\203\000\029\001\025\001\008\001\175\001\025\001\024\001\
\009\001\061\000\029\001\037\001\024\001\013\001\251\000\252\000\
\014\001\015\001\036\001\045\001\027\000\071\001\073\001\006\000\
\133\002\024\001\246\000\247\000\006\000\013\001\082\001\083\001\
\014\001\015\001\045\001\012\001\027\000\045\001\006\002\007\002\
\008\002\009\002\117\002\065\002\181\002\065\002\020\001\182\002\
\065\002\013\001\085\002\025\001\014\001\015\001\019\001\130\002\
\027\000\120\001\248\000\249\000\250\000\024\001\120\001\175\001\
\024\001\021\001\138\000\027\001\140\002\120\001\120\001\138\000\
\138\000\138\000\119\002\163\002\024\001\029\001\175\001\148\000\
\175\001\117\002\045\001\037\001\029\000\174\000\013\001\191\000\
\191\000\014\001\015\001\024\001\030\001\027\000\024\001\178\001\
\031\001\033\000\179\001\034\000\029\000\032\001\036\002\106\002\
\003\001\004\001\120\001\253\000\254\000\024\001\127\000\037\001\
\017\001\033\000\038\001\034\000\040\001\045\001\187\002\045\001\
\029\000\068\002\180\001\068\002\024\001\013\001\068\002\042\001\
\014\001\015\001\041\001\177\002\027\000\033\000\086\001\034\000\
\097\001\210\002\120\001\121\001\162\002\018\002\074\001\075\001\
\076\001\077\001\078\001\079\001\117\001\118\001\119\001\045\001\
\214\002\255\000\000\001\001\001\002\001\029\000\048\001\180\001\
\047\001\013\001\051\000\049\001\014\001\015\001\128\001\129\001\
\027\000\033\002\033\000\075\002\034\000\057\001\179\001\122\001\
\123\001\070\002\200\001\151\000\061\001\224\000\091\000\047\001\
\033\002\092\000\045\001\093\000\074\000\045\001\068\001\018\002\
\045\001\045\001\045\001\047\001\029\000\065\001\180\001\220\002\
\062\001\047\001\047\001\047\001\069\001\094\000\080\001\075\002\
\095\000\033\000\089\001\034\000\249\002\096\000\097\000\090\001\
\174\000\047\001\174\000\190\002\191\002\174\000\244\000\244\000\
\091\001\027\001\024\001\230\002\092\001\024\001\148\000\018\002\
\029\000\027\001\098\000\099\000\100\000\191\000\191\000\101\000\
\102\000\192\002\193\002\103\000\093\001\033\000\121\001\034\000\
\206\000\206\000\140\001\104\000\130\001\121\001\121\001\047\001\
\098\001\044\000\131\001\047\001\047\001\099\001\100\001\002\002\
\003\002\133\001\236\002\105\000\190\001\124\001\125\001\126\001\
\127\001\157\001\158\001\159\001\160\001\236\002\132\001\236\002\
\075\000\076\000\139\001\101\001\102\001\138\001\103\001\004\002\
\005\002\104\001\121\001\174\000\010\002\011\002\141\001\228\000\
\228\000\153\001\154\001\161\001\162\001\228\000\142\001\190\001\
\228\000\228\000\228\000\228\000\228\000\228\000\145\001\228\000\
\228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
\228\000\228\000\228\000\228\000\228\000\228\000\228\000\146\001\
\254\001\255\001\000\002\001\002\001\002\001\002\001\002\001\002\
\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\
\001\002\001\002\086\000\147\001\086\000\168\001\228\000\086\000\
\086\000\086\000\086\000\086\000\111\001\111\001\111\001\169\001\
\111\001\111\001\155\001\156\001\228\000\228\000\111\001\185\001\
\228\000\170\001\228\000\228\000\228\000\111\001\111\001\020\002\
\021\002\184\001\187\001\192\001\202\001\203\001\204\001\211\001\
\112\001\112\001\112\001\213\001\112\001\112\001\228\000\228\000\
\212\001\228\000\112\001\214\001\221\001\215\001\217\001\218\001\
\220\001\112\001\112\001\228\000\228\001\228\000\217\000\217\000\
\227\001\229\001\111\001\228\000\217\000\228\000\230\001\217\000\
\217\000\217\000\217\000\217\000\217\000\234\001\217\000\217\000\
\217\000\217\000\217\000\217\000\217\000\217\000\217\000\217\000\
\217\000\217\000\217\000\217\000\217\000\217\000\112\001\235\001\
\094\002\081\001\081\001\081\001\081\001\081\001\081\001\081\001\
\081\001\081\001\081\001\081\001\022\002\081\001\081\001\081\001\
\070\000\081\001\081\001\081\001\081\001\217\000\023\002\081\001\
\081\000\024\002\025\002\082\000\083\000\040\002\081\001\081\001\
\086\000\043\002\044\002\217\000\217\000\072\002\078\002\217\000\
\080\002\217\000\217\000\217\000\081\002\086\002\087\002\088\002\
\089\002\095\002\090\002\098\002\142\000\096\002\143\000\093\002\
\113\001\113\001\102\002\113\001\113\001\217\000\217\000\097\002\
\217\000\113\001\226\001\081\001\100\002\103\002\137\001\109\002\
\113\001\113\001\217\000\104\002\217\000\223\000\223\000\105\002\
\111\002\108\002\217\000\223\000\217\000\112\002\223\000\223\000\
\223\000\223\000\223\000\223\000\114\002\223\000\223\000\223\000\
\223\000\223\000\223\000\223\000\223\000\223\000\223\000\223\000\
\223\000\223\000\223\000\223\000\223\000\113\001\115\002\103\001\
\103\001\103\001\103\001\103\001\103\001\120\002\124\002\131\002\
\125\002\126\002\134\002\103\001\103\001\103\001\138\002\103\001\
\103\001\145\002\001\002\147\002\223\000\103\001\149\002\150\002\
\151\002\155\002\159\002\115\001\103\001\103\001\115\001\115\001\
\172\002\173\002\223\000\223\000\115\001\176\002\223\000\178\002\
\223\000\223\000\223\000\115\001\115\001\184\002\185\002\194\002\
\198\002\199\002\200\002\202\002\076\000\076\000\076\000\201\002\
\076\000\076\000\203\002\207\002\223\000\223\000\076\000\223\000\
\076\000\103\001\208\002\076\000\076\000\076\000\076\000\076\000\
\076\000\223\000\212\002\223\000\218\000\218\000\216\002\218\002\
\115\001\223\000\218\000\223\000\221\002\218\000\218\000\218\000\
\218\000\218\000\218\000\224\002\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
\218\000\218\000\218\000\218\000\065\001\065\001\065\001\065\001\
\065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
\065\001\225\002\065\001\065\001\065\001\226\002\065\001\065\001\
\065\001\065\001\227\002\218\000\065\001\228\002\232\002\240\002\
\241\002\243\002\242\002\065\001\065\001\245\002\252\002\253\002\
\254\002\218\000\218\000\246\002\003\001\218\000\006\000\218\000\
\218\000\218\000\236\000\045\001\045\001\045\001\045\001\045\001\
\045\001\045\001\045\001\045\001\078\000\078\000\002\003\078\000\
\078\000\189\000\015\001\218\000\218\000\078\000\218\000\078\000\
\065\001\005\001\078\000\078\000\078\000\078\000\078\000\078\000\
\218\000\021\000\218\000\045\001\045\001\045\001\108\001\108\001\
\218\000\122\001\218\000\035\001\022\000\242\000\006\000\134\000\
\121\000\136\000\108\001\108\001\108\001\152\000\108\001\108\001\
\045\001\045\001\045\001\159\000\108\001\045\001\045\001\119\000\
\141\000\045\001\045\001\108\001\108\001\127\001\045\001\045\001\
\045\001\045\001\132\001\045\001\045\001\045\001\045\001\045\001\
\045\001\155\000\136\000\136\000\114\001\114\001\140\001\114\001\
\114\001\142\001\144\001\053\000\010\001\114\001\206\002\209\002\
\042\002\201\001\122\002\173\001\114\001\114\001\045\001\045\001\
\108\001\045\001\084\002\121\002\023\001\045\001\045\001\012\002\
\014\002\016\002\161\002\013\002\154\002\231\002\015\002\163\001\
\045\001\045\001\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\114\001\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\079\002\104\001\104\001\104\001\
\104\001\104\001\104\001\195\002\164\001\166\001\165\001\250\002\
\251\002\104\001\104\001\104\001\167\001\104\001\104\001\157\000\
\157\000\157\000\003\003\104\001\157\000\157\000\000\000\000\000\
\157\000\157\000\104\001\104\001\000\000\157\000\157\000\000\000\
\157\000\157\000\157\000\000\000\000\000\000\000\157\000\000\000\
\000\000\000\000\157\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\157\000\157\000\157\000\000\000\000\000\
\000\000\157\000\157\000\157\000\157\000\157\000\157\000\104\001\
\157\000\000\000\000\000\157\000\157\000\157\000\157\000\157\000\
\157\000\157\000\157\000\000\000\000\000\000\000\157\000\157\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\000\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\000\000\105\001\105\001\105\001\105\001\105\001\
\105\001\000\000\000\000\000\000\000\000\000\000\000\000\105\001\
\105\001\105\001\000\000\105\001\105\001\150\000\150\000\150\000\
\000\000\105\001\150\000\150\000\000\000\000\000\150\000\150\000\
\105\001\105\001\000\000\150\000\150\000\000\000\150\000\150\000\
\150\000\000\000\000\000\000\000\150\000\000\000\000\000\000\000\
\150\000\150\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\150\000\150\000\150\000\000\000\000\000\000\000\150\000\
\150\000\150\000\150\000\150\000\150\000\105\001\150\000\000\000\
\000\000\000\000\150\000\150\000\150\000\150\000\150\000\150\000\
\150\000\000\000\000\000\000\000\150\000\150\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\000\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\000\000\106\001\106\001\106\001\106\001\106\001\106\001\000\000\
\000\000\000\000\000\000\000\000\000\000\106\001\106\001\106\001\
\000\000\106\001\106\001\164\000\164\000\164\000\000\000\106\001\
\164\000\164\000\000\000\000\000\164\000\164\000\106\001\106\001\
\000\000\164\000\164\000\000\000\164\000\164\000\164\000\000\000\
\000\000\000\000\164\000\000\000\000\000\000\000\164\000\164\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\164\000\
\164\000\164\000\000\000\000\000\000\000\164\000\164\000\164\000\
\164\000\164\000\164\000\106\001\164\000\000\000\000\000\000\000\
\164\000\164\000\164\000\164\000\164\000\164\000\164\000\000\000\
\000\000\000\000\164\000\164\000\046\002\047\002\180\000\181\000\
\182\000\183\000\005\000\074\000\184\000\006\000\007\000\008\000\
\009\000\010\000\011\000\000\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\068\000\022\000\023\000\
\024\000\025\000\026\000\027\000\185\000\186\000\000\000\107\001\
\107\001\107\001\107\001\107\001\107\001\000\000\000\000\000\000\
\000\000\000\000\000\000\107\001\107\001\107\001\000\000\107\001\
\107\001\187\000\188\000\189\000\000\000\107\001\190\000\191\000\
\000\000\000\000\192\000\193\000\107\001\107\001\000\000\194\000\
\195\000\000\000\196\000\000\000\138\000\000\000\000\000\000\000\
\048\002\000\000\000\000\000\000\049\002\050\002\051\002\052\002\
\053\002\054\002\055\002\056\002\057\002\058\002\059\002\060\002\
\000\000\000\000\000\000\029\000\030\000\061\002\032\000\075\000\
\076\000\107\001\197\000\000\000\000\000\000\000\198\000\199\000\
\033\000\062\002\034\000\035\000\036\000\000\000\000\000\000\000\
\039\000\200\000\084\001\179\000\180\000\181\000\182\000\183\000\
\005\000\074\000\184\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\068\000\022\000\023\000\024\000\025\000\
\026\000\027\000\185\000\186\000\000\000\109\001\109\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\109\001\109\001\109\001\000\000\109\001\109\001\187\000\
\188\000\189\000\000\000\109\001\190\000\191\000\000\000\000\000\
\192\000\193\000\109\001\109\001\000\000\194\000\195\000\000\000\
\196\000\000\000\138\000\077\000\077\000\077\000\000\000\077\000\
\077\000\000\000\000\000\000\000\000\000\077\000\000\000\077\000\
\000\000\000\000\077\000\077\000\077\000\077\000\077\000\077\000\
\000\000\029\000\030\000\000\000\032\000\075\000\076\000\109\001\
\197\000\000\000\000\000\000\000\198\000\199\000\033\000\000\000\
\034\000\000\000\000\000\000\000\000\000\000\000\039\000\200\000\
\238\001\179\000\180\000\181\000\182\000\183\000\005\000\074\000\
\184\000\006\000\007\000\008\000\009\000\010\000\011\000\000\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\068\000\022\000\023\000\024\000\025\000\026\000\027\000\
\185\000\186\000\000\000\110\001\110\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\110\001\
\110\001\110\001\000\000\110\001\110\001\187\000\188\000\189\000\
\000\000\110\001\190\000\191\000\000\000\000\000\192\000\193\000\
\110\001\110\001\000\000\194\000\195\000\000\000\196\000\046\002\
\136\002\180\000\181\000\182\000\183\000\084\000\074\000\184\000\
\000\000\000\000\084\000\000\000\084\000\000\000\000\000\084\000\
\084\000\084\000\084\000\084\000\084\000\000\000\000\000\029\000\
\030\000\000\000\032\000\075\000\076\000\110\001\197\000\185\000\
\186\000\000\000\198\000\199\000\033\000\000\000\034\000\116\001\
\000\000\000\000\116\001\116\001\039\000\200\000\000\000\000\000\
\116\001\000\000\000\000\000\000\187\000\188\000\189\000\116\001\
\116\001\190\000\191\000\117\001\117\001\192\000\193\000\000\000\
\000\000\117\001\194\000\195\000\000\000\196\000\000\000\138\000\
\117\001\117\001\000\000\048\002\000\000\000\000\000\000\049\002\
\050\002\051\002\052\002\053\002\054\002\055\002\056\002\057\002\
\058\002\059\002\060\002\000\000\116\001\000\000\000\000\000\000\
\061\002\000\000\075\000\076\000\000\000\197\000\000\000\000\000\
\000\000\198\000\199\000\000\000\062\002\117\001\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\026\002\180\000\181\000\
\182\000\183\000\057\000\074\000\184\000\000\000\000\000\118\001\
\118\001\000\000\000\000\082\000\082\000\118\001\000\000\000\000\
\000\000\082\000\000\000\082\000\118\001\118\001\082\000\082\000\
\082\000\082\000\082\000\082\000\185\000\186\000\091\000\000\000\
\000\000\092\000\000\000\093\000\074\000\000\000\000\000\000\000\
\000\000\000\000\027\002\000\000\000\000\000\000\000\000\000\000\
\000\000\187\000\188\000\189\000\000\000\094\000\190\000\191\000\
\095\000\118\001\192\000\193\000\000\000\096\000\097\000\194\000\
\195\000\000\000\196\000\000\000\174\001\028\002\000\000\000\000\
\238\001\179\000\180\000\181\000\182\000\183\000\000\000\074\000\
\184\000\000\000\098\000\099\000\100\000\000\000\000\000\101\000\
\102\000\000\000\000\000\103\000\000\000\000\000\000\000\075\000\
\076\000\000\000\197\000\104\000\000\000\000\000\198\000\199\000\
\185\000\186\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\200\000\061\000\105\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\187\000\188\000\189\000\
\075\000\076\000\190\000\191\000\000\000\000\000\192\000\193\000\
\000\000\000\000\000\000\194\000\195\000\000\000\196\000\000\000\
\000\000\000\000\000\000\000\000\129\002\045\001\045\001\045\001\
\045\001\045\001\045\001\085\000\045\001\045\001\000\000\000\000\
\085\000\000\000\085\000\000\000\000\000\085\000\085\000\085\000\
\085\000\085\000\085\000\075\000\076\000\000\000\197\000\000\000\
\000\000\000\000\198\000\199\000\000\000\045\001\045\001\000\000\
\083\000\083\000\000\000\000\000\000\000\200\000\083\000\000\000\
\083\000\000\000\000\000\083\000\083\000\083\000\083\000\083\000\
\083\000\000\000\045\001\045\001\045\001\000\000\000\000\045\001\
\045\001\000\000\000\000\045\001\045\001\000\000\000\000\000\000\
\045\001\045\001\000\000\045\001\000\000\000\000\000\000\045\001\
\000\000\238\001\179\000\180\000\181\000\182\000\183\000\000\000\
\074\000\184\000\106\001\107\001\108\001\109\001\110\001\111\001\
\112\001\113\001\114\001\115\001\116\001\000\000\000\000\000\000\
\045\001\045\001\000\000\045\001\000\000\000\000\000\000\045\001\
\045\001\185\000\186\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\045\001\243\001\244\001\245\001\246\001\247\001\
\248\001\249\001\250\001\251\001\252\001\253\001\187\000\188\000\
\189\000\000\000\000\000\190\000\191\000\000\000\000\000\192\000\
\193\000\000\000\000\000\000\000\194\000\195\000\000\000\196\000\
\241\001\179\000\180\000\181\000\182\000\183\000\000\000\074\000\
\184\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\116\002\179\000\180\000\181\000\182\000\
\183\000\000\000\074\000\184\000\075\000\076\000\000\000\197\000\
\185\000\186\000\000\000\198\000\199\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\200\000\000\000\
\000\000\000\000\000\000\185\000\186\000\187\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\192\000\193\000\
\000\000\000\000\000\000\194\000\195\000\000\000\196\000\000\000\
\187\000\188\000\189\000\000\000\000\000\190\000\191\000\000\000\
\000\000\192\000\193\000\000\000\000\000\000\000\194\000\195\000\
\000\000\196\000\179\002\179\000\180\000\181\000\182\000\183\000\
\000\000\074\000\184\000\075\000\076\000\000\000\197\000\000\000\
\000\000\000\000\198\000\199\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\200\000\075\000\076\000\
\000\000\197\000\185\000\186\000\000\000\198\000\199\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\200\000\000\000\000\000\000\000\000\000\000\000\000\000\187\000\
\188\000\189\000\000\000\000\000\190\000\191\000\000\000\000\000\
\192\000\193\000\000\000\000\000\000\000\194\000\195\000\000\000\
\196\000\248\002\179\000\180\000\181\000\182\000\183\000\080\000\
\074\000\184\000\080\000\080\000\000\000\000\000\000\000\000\000\
\080\000\000\000\080\000\000\000\000\000\080\000\080\000\080\000\
\080\000\080\000\080\000\000\000\000\000\075\000\076\000\000\000\
\197\000\185\000\186\000\000\000\198\000\199\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\200\000\
\000\000\000\000\000\000\000\000\000\000\000\000\187\000\188\000\
\189\000\000\000\000\000\190\000\191\000\000\000\000\000\192\000\
\193\000\000\000\000\000\000\000\194\000\195\000\000\000\196\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\068\000\068\000\068\000\068\000\068\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\068\000\068\000\
\068\000\000\000\068\000\068\000\075\000\076\000\000\000\197\000\
\068\000\000\000\068\000\198\000\199\000\068\000\068\000\068\000\
\068\000\068\000\068\000\000\000\000\000\000\000\200\000\179\000\
\180\000\181\000\182\000\183\000\005\000\074\000\184\000\006\000\
\007\000\008\000\009\000\010\000\011\000\000\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\068\000\
\022\000\023\000\024\000\025\000\026\000\027\000\185\000\186\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\187\000\188\000\189\000\000\000\000\000\
\190\000\191\000\000\000\000\000\192\000\193\000\000\000\000\000\
\000\000\194\000\195\000\000\000\196\000\000\000\000\000\069\001\
\069\001\069\001\069\001\069\001\069\001\069\001\069\001\069\001\
\069\001\069\001\069\001\069\001\000\000\069\001\069\001\069\001\
\000\000\069\001\069\001\069\001\069\001\029\000\030\000\069\001\
\032\000\075\000\076\000\000\000\197\000\000\000\069\001\069\001\
\198\000\199\000\033\000\161\000\034\000\000\000\000\000\000\000\
\000\000\005\000\039\000\200\000\006\000\007\000\008\000\009\000\
\010\000\011\000\000\000\012\000\013\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\068\000\022\000\023\000\024\000\
\025\000\026\000\027\000\069\001\079\000\079\000\000\000\079\000\
\079\000\000\000\000\000\000\000\000\000\079\000\000\000\079\000\
\000\000\000\000\079\000\079\000\079\000\079\000\079\000\079\000\
\000\000\000\000\000\000\000\000\073\000\073\000\000\000\000\000\
\131\000\131\000\131\000\131\000\131\000\000\000\131\000\131\000\
\073\000\073\000\073\000\000\000\073\000\073\000\000\000\162\000\
\000\000\000\000\073\000\000\000\073\000\000\000\000\000\073\000\
\073\000\073\000\073\000\073\000\073\000\000\000\000\000\131\000\
\131\000\131\000\029\000\030\000\000\000\032\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\033\000\
\000\000\034\000\035\000\036\000\131\000\131\000\131\000\039\000\
\000\000\131\000\131\000\000\000\000\000\131\000\131\000\000\000\
\000\000\000\000\131\000\131\000\000\000\131\000\000\000\131\000\
\179\000\180\000\181\000\182\000\183\000\081\000\074\000\184\000\
\081\000\081\000\000\000\000\000\000\000\000\000\081\000\000\000\
\081\000\000\000\000\000\081\000\081\000\081\000\081\000\081\000\
\081\000\000\000\131\000\131\000\000\000\131\000\000\000\185\000\
\186\000\131\000\131\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\131\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\187\000\188\000\189\000\000\000\
\000\000\190\000\191\000\000\000\000\000\192\000\193\000\000\000\
\000\000\000\000\194\000\195\000\000\000\196\000\000\000\174\001\
\179\000\180\000\181\000\182\000\183\000\000\000\074\000\184\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\075\000\076\000\000\000\197\000\000\000\185\000\
\186\000\198\000\199\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\187\000\188\000\189\000\000\000\
\000\000\190\000\191\000\000\000\000\000\192\000\193\000\000\000\
\000\000\000\000\194\000\195\000\000\000\196\000\000\000\093\002\
\127\000\127\000\127\000\127\000\127\000\000\000\127\000\127\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\075\000\076\000\000\000\197\000\000\000\127\000\
\127\000\198\000\199\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\127\000\127\000\127\000\000\000\
\000\000\127\000\127\000\000\000\000\000\127\000\127\000\000\000\
\000\000\000\000\127\000\127\000\000\000\127\000\000\000\127\000\
\179\000\180\000\181\000\182\000\183\000\000\000\074\000\184\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\127\000\127\000\000\000\127\000\000\000\185\000\
\186\000\127\000\127\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\127\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\187\000\188\000\189\000\000\000\
\000\000\190\000\191\000\000\000\000\000\192\000\193\000\000\000\
\000\000\000\000\194\000\195\000\000\000\232\000\000\000\179\000\
\180\000\181\000\182\000\183\000\000\000\074\000\184\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\179\000\180\000\181\000\182\000\183\000\000\000\
\074\000\184\000\075\000\076\000\000\000\197\000\185\000\186\000\
\000\000\198\000\199\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\000\000\000\000\000\000\
\000\000\185\000\186\000\187\000\188\000\189\000\000\000\000\000\
\190\000\191\000\000\000\000\000\192\000\193\000\000\000\000\000\
\000\000\194\000\195\000\000\000\234\000\000\000\187\000\188\000\
\189\000\000\000\000\000\190\000\191\000\000\000\000\000\192\000\
\193\000\000\000\000\000\000\000\194\000\195\000\000\000\196\000\
\000\000\179\000\180\000\181\000\182\000\183\000\000\000\074\000\
\184\000\075\000\076\000\000\000\197\000\000\000\000\000\000\000\
\198\000\199\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\200\000\075\000\076\000\000\000\197\000\
\185\000\186\000\000\000\198\000\199\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\200\000\000\000\
\000\000\000\000\000\000\000\000\000\000\187\000\188\000\189\000\
\000\000\000\000\190\000\191\000\000\000\000\000\192\000\193\000\
\000\000\000\000\000\000\194\000\195\000\000\000\070\001\000\000\
\179\000\180\000\181\000\182\000\183\000\000\000\074\000\184\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\179\000\180\000\181\000\182\000\183\000\
\000\000\074\000\184\000\075\000\076\000\000\000\197\000\185\000\
\186\000\000\000\198\000\199\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\200\000\000\000\000\000\
\000\000\000\000\185\000\186\000\187\000\188\000\189\000\000\000\
\000\000\190\000\191\000\000\000\000\000\192\000\193\000\000\000\
\000\000\000\000\194\000\195\000\000\000\072\001\000\000\187\000\
\188\000\189\000\000\000\000\000\190\000\191\000\000\000\000\000\
\192\000\193\000\000\000\000\000\000\000\194\000\195\000\000\000\
\081\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\075\000\076\000\000\000\197\000\000\000\000\000\
\000\000\198\000\199\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\200\000\075\000\076\000\000\000\
\197\000\004\000\000\000\000\000\198\000\199\000\005\000\000\000\
\000\000\006\000\007\000\008\000\009\000\010\000\011\000\200\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\026\000\027\000\
\004\000\000\000\000\000\000\000\000\000\005\000\000\000\000\000\
\006\000\007\000\008\000\009\000\010\000\011\000\000\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\026\000\027\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\100\001\100\001\
\100\001\100\001\100\001\100\001\028\000\000\000\000\000\000\000\
\000\000\000\000\100\001\100\001\100\001\000\000\100\001\100\001\
\100\001\100\001\000\000\000\000\100\001\000\000\000\000\029\000\
\030\000\031\000\032\000\100\001\100\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\033\000\000\000\034\000\035\000\
\036\000\000\000\037\000\038\000\039\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\029\000\030\000\
\031\000\032\000\000\000\000\000\000\000\000\000\000\000\000\000\
\100\001\000\000\000\000\033\000\000\000\034\000\035\000\036\000\
\000\000\037\000\038\000\039\000\107\000\000\000\000\000\107\000\
\107\000\107\000\107\000\107\000\107\000\000\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\000\000\000\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\000\000\107\000\107\000\107\000\000\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\107\000\107\000\000\000\
\107\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\107\000\000\000\107\000\000\000\000\000\107\000\
\005\000\074\000\107\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\068\000\022\000\023\000\024\000\025\000\
\026\000\027\000\000\000\005\000\000\000\000\000\006\000\007\000\
\008\000\009\000\010\000\011\000\000\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\068\000\022\000\
\023\000\024\000\025\000\026\000\027\000\000\000\000\000\000\000\
\000\000\002\001\000\000\000\000\002\001\002\001\002\001\002\001\
\002\001\002\001\000\000\002\001\002\001\002\001\002\001\002\001\
\002\001\002\001\002\001\002\001\002\001\002\001\002\001\002\001\
\002\001\002\001\002\001\000\000\000\000\000\000\000\000\000\000\
\000\000\029\000\030\000\147\000\032\000\075\000\076\000\000\000\
\000\000\000\000\000\000\197\001\000\000\000\000\033\000\000\000\
\034\000\000\000\000\000\000\000\000\000\000\000\039\000\074\000\
\074\000\000\000\000\000\000\000\029\000\030\000\000\000\032\000\
\002\001\002\001\000\000\074\000\074\000\074\000\000\000\074\000\
\074\000\033\000\000\000\034\000\000\000\074\000\000\000\074\000\
\000\000\039\000\074\000\074\000\074\000\074\000\074\000\074\000\
\000\000\000\000\002\001\002\001\000\000\002\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\002\001\
\000\000\002\001\000\000\000\000\000\000\005\000\000\000\002\001\
\006\000\007\000\008\000\009\000\010\000\011\000\000\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\068\000\022\000\023\000\024\000\025\000\026\000\027\000\000\000\
\005\000\000\000\000\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\068\000\022\000\023\000\024\000\025\000\
\026\000\027\000\000\000\000\000\005\000\000\000\000\000\006\000\
\007\000\008\000\009\000\010\000\011\000\147\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\068\000\
\022\000\023\000\024\000\025\000\026\000\027\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\029\000\030\000\
\000\000\032\000\173\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\033\000\000\000\034\000\000\000\000\000\
\000\000\000\000\000\000\039\000\000\000\000\000\000\000\000\000\
\000\000\029\000\030\000\000\000\032\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\196\002\000\000\033\000\000\000\
\034\000\000\000\000\000\000\000\000\000\000\000\039\000\000\000\
\000\000\000\000\000\000\000\000\000\000\029\000\030\000\000\000\
\032\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\033\000\000\000\034\000\000\000\000\000\000\000\
\005\000\000\000\039\000\006\000\007\000\008\000\009\000\010\000\
\011\000\000\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\068\000\022\000\023\000\024\000\025\000\
\026\000\027\000\006\000\007\000\008\000\009\000\010\000\011\000\
\000\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\068\000\022\000\023\000\024\000\025\000\026\000\
\027\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\224\000\091\000\000\000\000\000\092\000\000\000\093\000\074\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\094\000\029\000\030\000\095\000\032\000\000\000\000\000\000\000\
\096\000\097\000\000\000\000\000\000\000\000\000\033\000\000\000\
\034\000\000\000\000\000\000\000\000\000\000\000\039\000\000\000\
\029\000\030\000\000\000\032\000\000\000\098\000\099\000\100\000\
\000\000\000\000\101\000\102\000\000\000\033\000\103\000\034\000\
\000\000\000\000\000\000\000\000\000\000\039\000\104\000\019\002\
\091\000\000\000\000\000\092\000\000\000\093\000\074\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\105\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\094\000\
\000\000\000\000\095\000\075\000\076\000\000\000\000\000\096\000\
\097\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\098\000\099\000\100\000\000\000\
\000\000\101\000\102\000\000\000\000\000\103\000\101\001\101\001\
\101\001\101\001\101\001\101\001\000\000\104\000\000\000\000\000\
\000\000\000\000\101\001\101\001\101\001\000\000\101\001\101\001\
\101\001\101\001\000\000\000\000\101\001\105\000\000\000\000\000\
\000\000\000\000\000\000\101\001\101\001\000\000\000\000\000\000\
\000\000\000\000\075\000\076\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\000\000\106\000\106\000\106\000\
\101\001\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\000\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\042\000\042\000\042\000\042\000\042\000\042\000\
\042\000\042\000\042\000\042\000\042\000\000\000\000\000\042\000\
\042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
\042\000\042\000\000\000\042\000\042\000\042\000\000\000\042\000\
\042\000\042\000\042\000\106\000\000\000\042\000\000\000\042\000\
\000\000\000\000\042\000\042\000\042\000\042\000\042\000\042\000\
\046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
\046\000\046\000\046\000\000\000\000\000\046\000\046\000\046\000\
\046\000\046\000\046\000\046\000\046\000\046\000\046\000\046\000\
\000\000\046\000\046\000\046\000\000\000\046\000\046\000\046\000\
\046\000\042\000\000\000\046\000\000\000\046\000\000\000\000\000\
\046\000\046\000\046\000\046\000\046\000\046\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
\048\000\000\000\000\000\048\000\048\000\048\000\048\000\048\000\
\048\000\048\000\048\000\048\000\048\000\048\000\000\000\048\000\
\048\000\048\000\000\000\048\000\048\000\048\000\048\000\046\000\
\000\000\048\000\000\000\048\000\000\000\000\000\048\000\048\000\
\048\000\048\000\048\000\048\000\083\001\083\001\083\001\083\001\
\083\001\083\001\083\001\083\001\083\001\083\001\083\001\000\000\
\083\001\083\001\083\001\000\000\083\001\083\001\083\001\083\001\
\000\000\000\000\083\001\000\000\000\000\000\000\000\000\000\000\
\000\000\083\001\083\001\000\000\000\000\048\000\085\001\085\001\
\085\001\085\001\085\001\085\001\085\001\085\001\085\001\085\001\
\085\001\000\000\085\001\085\001\085\001\000\000\085\001\085\001\
\085\001\085\001\000\000\000\000\085\001\000\000\000\000\000\000\
\000\000\000\000\000\000\085\001\085\001\000\000\083\001\097\001\
\097\001\097\001\097\001\097\001\097\001\097\001\097\001\000\000\
\000\000\000\000\000\000\097\001\097\001\097\001\000\000\097\001\
\097\001\097\001\097\001\000\000\000\000\097\001\000\000\000\000\
\000\000\000\000\000\000\000\000\097\001\097\001\000\000\000\000\
\085\001\098\001\098\001\098\001\098\001\098\001\098\001\098\001\
\098\001\000\000\000\000\000\000\000\000\098\001\098\001\098\001\
\000\000\098\001\098\001\098\001\098\001\000\000\000\000\098\001\
\000\000\000\000\000\000\000\000\000\000\000\000\098\001\098\001\
\000\000\097\001\099\001\099\001\099\001\099\001\099\001\099\001\
\099\001\099\001\000\000\000\000\000\000\000\000\099\001\099\001\
\099\001\000\000\099\001\099\001\099\001\099\001\000\000\000\000\
\099\001\102\001\102\001\102\001\102\001\102\001\102\001\099\001\
\099\001\000\000\000\000\098\001\000\000\102\001\102\001\102\001\
\000\000\102\001\102\001\102\001\102\001\000\000\000\000\102\001\
\000\000\000\000\000\000\000\000\000\000\000\000\102\001\102\001\
\000\000\058\000\058\000\058\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\099\001\058\000\058\000\058\000\
\000\000\058\000\058\000\058\000\058\000\000\000\000\000\058\000\
\000\000\058\000\000\000\000\000\058\000\058\000\058\000\058\000\
\058\000\058\000\000\000\102\001\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\000\000\023\000\023\000\023\000\
\000\000\023\000\023\000\023\000\023\000\023\000\023\000\000\000\
\023\000\023\000\000\000\023\000\000\000\018\000\000\000\023\000\
\000\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\023\000\023\000\023\000\023\000\023\000\023\000\
\023\000\023\000\000\000\023\000\023\000\023\000\000\000\023\000\
\023\000\023\000\023\000\023\000\023\000\000\000\023\000\000\000\
\000\000\023\000\000\000\000\000\023\000\023\000\000\000\023\000\
\062\000\062\000\062\000\062\000\062\000\062\000\062\000\062\000\
\000\000\000\000\000\000\000\000\062\000\062\000\062\000\000\000\
\062\000\062\000\062\000\062\000\000\000\000\000\062\000\000\000\
\062\000\000\000\000\000\062\000\062\000\062\000\062\000\062\000\
\062\000\063\000\063\000\063\000\063\000\063\000\063\000\063\000\
\063\000\000\000\000\000\000\000\000\000\063\000\063\000\063\000\
\000\000\063\000\063\000\063\000\063\000\000\000\000\000\063\000\
\000\000\063\000\000\000\000\000\063\000\063\000\063\000\063\000\
\063\000\063\000\064\000\064\000\064\000\064\000\064\000\064\000\
\064\000\064\000\000\000\000\000\000\000\000\000\064\000\064\000\
\064\000\000\000\064\000\064\000\064\000\064\000\000\000\000\000\
\064\000\000\000\064\000\000\000\000\000\064\000\064\000\064\000\
\064\000\064\000\064\000\065\000\065\000\065\000\065\000\065\000\
\065\000\000\000\000\000\000\000\000\000\000\000\000\000\065\000\
\065\000\065\000\000\000\065\000\065\000\065\000\065\000\000\000\
\000\000\065\000\000\000\065\000\000\000\000\000\065\000\065\000\
\065\000\065\000\065\000\065\000\066\000\066\000\066\000\066\000\
\066\000\066\000\000\000\000\000\000\000\000\000\000\000\000\000\
\066\000\066\000\066\000\000\000\066\000\066\000\066\000\066\000\
\000\000\000\000\066\000\000\000\066\000\000\000\000\000\066\000\
\066\000\066\000\066\000\066\000\066\000\067\000\067\000\067\000\
\067\000\067\000\067\000\000\000\000\000\000\000\000\000\000\000\
\000\000\067\000\067\000\067\000\000\000\067\000\067\000\067\000\
\067\000\000\000\000\000\067\000\000\000\067\000\000\000\000\000\
\067\000\067\000\067\000\067\000\067\000\067\000\069\000\069\000\
\069\000\069\000\069\000\069\000\000\000\000\000\000\000\000\000\
\000\000\000\000\069\000\069\000\069\000\000\000\069\000\069\000\
\000\000\000\000\000\000\000\000\069\000\000\000\069\000\000\000\
\000\000\069\000\069\000\069\000\069\000\069\000\069\000\070\000\
\070\000\070\000\070\000\070\000\070\000\000\000\000\000\000\000\
\000\000\000\000\000\000\070\000\070\000\070\000\000\000\070\000\
\070\000\000\000\000\000\000\000\000\000\070\000\000\000\070\000\
\000\000\000\000\070\000\070\000\070\000\070\000\070\000\070\000\
\071\000\071\000\071\000\071\000\071\000\071\000\000\000\000\000\
\000\000\000\000\000\000\000\000\071\000\071\000\071\000\000\000\
\071\000\071\000\000\000\000\000\000\000\000\000\071\000\000\000\
\071\000\000\000\000\000\071\000\071\000\071\000\071\000\071\000\
\071\000\072\000\072\000\072\000\072\000\072\000\072\000\000\000\
\000\000\000\000\000\000\000\000\000\000\072\000\072\000\072\000\
\000\000\072\000\072\000\000\000\000\000\000\000\000\000\072\000\
\000\000\072\000\075\000\075\000\072\000\072\000\072\000\072\000\
\072\000\072\000\000\000\000\000\000\000\000\000\075\000\075\000\
\075\000\000\000\075\000\075\000\000\000\000\000\000\000\000\000\
\075\000\000\000\075\000\000\000\000\000\075\000\075\000\075\000\
\075\000\075\000\075\000"

let yycheck = "\021\000\
\048\000\077\000\088\000\001\000\002\000\004\000\137\000\021\001\
\028\000\000\000\127\000\148\000\000\000\000\000\036\000\182\001\
\044\000\147\000\060\000\046\001\047\001\030\001\023\001\043\000\
\078\000\044\000\196\000\036\000\106\002\000\001\028\000\000\001\
\012\000\013\000\046\001\015\000\138\002\123\000\001\001\000\001\
\018\001\157\000\158\000\085\000\022\001\043\000\001\001\001\001\
\076\001\091\000\070\001\006\001\055\001\001\001\115\002\001\001\
\000\001\053\002\006\001\148\000\056\002\073\001\232\000\059\002\
\234\000\087\000\001\001\089\000\070\001\206\000\055\001\006\001\
\075\001\076\001\055\001\064\001\098\000\099\000\100\000\101\000\
\102\000\103\000\104\000\063\000\055\001\113\001\188\002\067\000\
\166\002\150\002\079\001\076\001\055\001\073\000\075\001\104\000\
\070\001\001\001\001\000\002\000\055\001\001\001\006\001\072\001\
\007\001\008\001\006\001\070\001\071\000\055\001\071\001\014\000\
\154\000\076\001\070\001\070\001\070\001\206\000\021\000\022\000\
\148\000\075\001\025\000\026\000\122\000\028\000\228\002\030\000\
\072\001\148\000\069\001\098\000\099\000\100\000\101\000\102\000\
\103\000\072\001\077\001\001\001\043\000\000\001\045\000\196\000\
\006\001\001\001\174\000\050\000\196\000\052\000\006\001\205\000\
\055\000\173\000\001\001\118\001\070\001\018\001\072\001\006\001\
\095\001\022\001\023\001\118\001\038\001\068\000\077\002\081\001\
\072\001\178\001\118\001\070\001\072\001\108\001\077\000\173\000\
\090\001\091\001\072\001\232\000\207\001\234\000\183\001\118\001\
\232\000\088\000\234\000\206\000\048\001\185\002\093\002\021\001\
\071\001\194\001\190\002\001\001\099\001\100\001\077\001\162\000\
\006\001\179\001\165\000\166\000\167\000\108\002\228\000\170\000\
\171\000\084\001\072\001\041\001\069\001\072\001\118\001\193\001\
\072\001\195\001\118\001\122\000\077\001\051\001\007\001\057\002\
\000\001\072\001\248\000\249\000\250\000\251\000\252\000\253\000\
\254\000\255\000\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\147\000\000\001\074\001\019\001\
\095\001\077\001\001\001\000\001\013\000\016\001\015\000\006\001\
\118\001\235\001\063\002\089\001\065\002\108\001\118\001\068\002\
\070\001\000\001\246\000\247\000\000\001\000\001\173\000\118\001\
\046\001\070\001\070\001\072\001\055\001\035\002\070\001\072\001\
\072\001\248\000\249\000\250\000\081\001\034\001\000\001\001\001\
\000\000\081\001\124\002\070\001\006\001\196\000\073\001\069\001\
\072\001\064\001\132\002\073\001\076\001\135\002\069\001\064\000\
\000\001\139\002\103\001\104\001\095\001\076\001\077\001\001\001\
\118\001\001\001\099\001\100\001\006\001\072\001\179\001\070\001\
\069\001\108\001\183\001\072\001\001\000\002\000\075\001\076\001\
\077\001\232\000\001\001\234\000\193\001\194\001\195\001\006\001\
\071\001\070\001\135\001\000\001\001\001\055\001\049\001\069\001\
\174\001\052\001\113\001\181\002\001\001\075\001\184\002\069\001\
\110\002\006\001\061\001\069\001\070\001\075\001\065\001\073\001\
\069\001\075\001\076\001\077\001\001\001\055\001\075\001\118\001\
\188\001\006\001\001\001\137\001\138\001\074\001\235\001\099\001\
\100\001\078\001\069\001\069\001\070\001\211\001\073\001\073\001\
\218\002\032\001\077\001\077\001\096\000\097\000\001\001\038\001\
\226\002\254\002\055\001\006\001\070\001\002\003\069\001\070\001\
\024\001\187\001\073\001\027\001\118\001\177\001\077\001\241\002\
\069\001\070\001\074\001\061\001\073\001\077\001\075\001\076\001\
\077\001\071\001\190\001\072\001\072\001\001\001\076\001\070\001\
\072\001\072\001\006\001\046\002\118\001\226\001\227\001\072\001\
\069\001\070\001\081\001\075\001\073\001\095\002\096\002\075\001\
\077\001\059\001\095\001\090\001\091\001\000\001\188\001\118\001\
\001\001\074\002\174\001\173\002\195\001\006\001\028\002\108\001\
\060\001\118\001\069\001\070\001\063\001\035\002\073\001\001\001\
\064\001\118\001\077\001\000\001\006\001\024\001\053\001\054\001\
\027\001\028\001\099\002\055\001\031\001\185\000\186\000\071\001\
\054\002\118\001\045\001\046\001\076\001\024\001\194\000\195\000\
\027\001\028\001\070\001\001\001\031\001\073\001\124\001\125\001\
\126\001\127\001\039\002\063\002\075\001\065\002\076\001\078\001\
\068\002\024\001\213\001\118\001\027\001\028\001\077\001\052\002\
\031\001\064\001\055\001\056\001\057\001\070\001\069\001\093\002\
\073\001\034\001\069\001\101\001\060\002\076\001\077\001\074\001\
\075\001\076\001\040\002\105\002\070\001\076\001\108\002\182\001\
\110\002\078\002\118\001\072\001\095\001\188\001\024\001\076\001\
\077\001\027\001\028\001\070\001\077\001\031\001\073\001\070\001\
\076\001\108\001\073\001\110\001\095\001\069\001\074\002\027\002\
\047\001\048\001\113\001\065\001\066\001\118\001\055\001\074\002\
\173\002\108\001\077\001\110\001\069\001\000\001\138\002\001\001\
\095\001\063\002\097\001\065\002\118\001\024\001\068\002\077\001\
\027\001\028\001\034\001\128\002\031\001\108\001\131\002\110\001\
\099\002\167\002\053\001\054\001\104\002\138\002\187\000\188\000\
\189\000\190\000\191\000\192\000\055\001\056\001\057\001\034\001\
\182\002\049\001\050\001\051\001\052\001\095\001\072\001\097\001\
\034\001\024\001\104\002\076\001\027\001\028\001\047\001\048\001\
\031\001\093\002\108\001\070\001\110\001\071\001\073\001\065\001\
\066\001\149\002\000\001\001\001\072\001\000\001\001\001\000\001\
\108\002\004\001\069\001\006\001\007\001\072\001\069\001\188\002\
\075\001\076\001\077\001\069\001\095\001\072\001\097\001\191\002\
\071\001\075\001\076\001\077\001\069\001\024\001\001\001\070\001\
\027\001\108\001\070\001\110\001\242\002\032\001\033\001\070\001\
\063\002\034\001\065\002\092\001\093\001\068\002\076\001\077\001\
\070\001\069\001\070\001\219\002\070\001\073\001\077\002\228\002\
\095\001\077\001\053\001\054\001\055\001\076\001\077\001\058\001\
\059\001\141\002\142\002\062\001\069\001\108\001\069\001\110\001\
\095\002\096\002\069\001\070\001\059\001\076\001\077\001\072\001\
\069\001\104\002\061\001\076\001\077\001\045\001\046\001\120\001\
\121\001\063\001\232\002\086\001\115\002\049\001\050\001\051\001\
\052\001\255\000\000\001\001\001\002\001\243\002\060\001\245\002\
\099\001\100\001\069\001\067\001\068\001\077\001\070\001\122\001\
\123\001\073\001\113\001\138\002\128\001\129\001\004\001\000\001\
\001\001\251\000\252\000\003\001\004\001\006\001\004\001\150\002\
\009\001\010\001\011\001\012\001\013\001\014\001\069\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\004\001\
\117\001\118\001\119\001\120\001\121\001\122\001\123\001\124\001\
\125\001\126\001\127\001\128\001\129\001\130\001\131\001\132\001\
\133\001\134\001\069\001\113\001\071\001\071\001\055\001\074\001\
\075\001\076\001\077\001\078\001\059\001\060\001\061\001\071\001\
\063\001\064\001\253\000\254\000\069\001\070\001\069\001\001\001\
\073\001\069\001\075\001\076\001\077\001\076\001\077\001\137\001\
\138\001\071\001\105\001\069\001\071\001\069\001\069\001\075\001\
\059\001\060\001\061\001\076\001\063\001\064\001\095\001\096\001\
\077\001\098\001\069\001\071\001\076\001\071\001\071\001\071\001\
\071\001\076\001\077\001\108\001\069\001\110\001\000\001\001\001\
\077\001\069\001\113\001\116\001\006\001\118\001\069\001\009\001\
\010\001\011\001\012\001\013\001\014\001\001\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\113\001\070\001\
\229\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\069\001\059\001\060\001\061\001\
\014\000\063\001\064\001\065\001\066\001\055\001\069\001\069\001\
\022\000\001\001\001\001\025\000\026\000\070\001\076\001\077\001\
\030\000\077\001\076\001\069\001\070\001\076\001\073\001\073\001\
\071\001\075\001\076\001\077\001\071\001\071\001\071\001\069\001\
\069\001\077\001\069\001\069\001\050\000\077\001\052\000\072\001\
\060\001\061\001\074\001\063\001\064\001\095\001\096\001\077\001\
\098\001\069\001\077\001\113\001\069\001\075\001\077\001\034\001\
\076\001\077\001\108\001\072\001\110\001\000\001\001\001\072\001\
\075\001\077\001\116\001\006\001\118\001\071\001\009\001\010\001\
\011\001\012\001\013\001\014\001\069\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\113\001\069\001\047\001\
\048\001\049\001\050\001\051\001\052\001\069\001\075\001\070\001\
\076\001\076\001\075\001\059\001\060\001\061\001\070\001\063\001\
\064\001\076\001\103\002\071\001\055\001\069\001\077\001\076\001\
\069\001\071\001\001\001\060\001\076\001\077\001\063\001\064\001\
\074\001\069\001\069\001\070\001\069\001\076\001\073\001\076\001\
\075\001\076\001\077\001\076\001\077\001\075\001\087\001\070\001\
\069\001\069\001\074\001\069\001\059\001\060\001\061\001\071\001\
\063\001\064\001\069\001\071\001\095\001\096\001\069\001\098\001\
\071\001\113\001\071\001\074\001\075\001\076\001\077\001\078\001\
\079\001\108\001\076\001\110\001\000\001\001\001\076\001\094\001\
\113\001\116\001\006\001\118\001\007\001\009\001\010\001\011\001\
\012\001\013\001\014\001\001\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\074\001\059\001\060\001\061\001\075\001\063\001\064\001\
\065\001\066\001\076\001\055\001\069\001\076\001\075\001\069\001\
\069\001\075\001\070\001\076\001\077\001\077\001\069\001\069\001\
\075\001\069\001\070\001\076\001\069\001\073\001\000\001\075\001\
\076\001\077\001\071\001\000\001\001\001\002\001\003\001\004\001\
\005\001\006\001\007\001\008\001\060\001\061\001\077\001\063\001\
\064\001\076\001\069\001\095\001\096\001\069\001\098\001\071\001\
\113\001\069\001\074\001\075\001\076\001\077\001\078\001\079\001\
\108\001\071\001\110\001\032\001\033\001\034\001\047\001\048\001\
\116\001\069\001\118\001\073\001\071\001\076\001\071\001\069\001\
\071\001\075\001\059\001\060\001\061\001\071\001\063\001\064\001\
\053\001\054\001\055\001\076\001\069\001\058\001\059\001\071\001\
\074\001\062\001\063\001\076\001\077\001\070\001\067\001\068\001\
\069\001\070\001\069\001\072\001\073\001\074\001\075\001\076\001\
\077\001\071\001\076\001\069\001\060\001\061\001\069\001\063\001\
\064\001\069\001\069\001\002\000\122\000\069\001\160\002\166\002\
\183\001\042\001\044\002\019\001\076\001\077\001\099\001\100\001\
\113\001\102\001\212\001\043\002\134\000\106\001\107\001\130\001\
\132\001\134\001\103\002\131\001\078\002\222\002\133\001\005\001\
\117\001\118\001\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\010\001\011\001\012\001\013\001\
\014\001\113\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\198\001\047\001\048\001\049\001\
\050\001\051\001\052\001\149\002\006\001\008\001\007\001\243\002\
\245\002\059\001\060\001\061\001\009\001\063\001\064\001\053\001\
\054\001\055\001\002\003\069\001\058\001\059\001\255\255\255\255\
\062\001\063\001\076\001\077\001\255\255\067\001\068\001\255\255\
\070\001\071\001\072\001\255\255\255\255\255\255\076\001\255\255\
\255\255\255\255\080\001\081\001\082\001\083\001\084\001\085\001\
\086\001\087\001\088\001\089\001\090\001\091\001\255\255\255\255\
\255\255\095\001\096\001\097\001\098\001\099\001\100\001\113\001\
\102\001\255\255\255\255\105\001\106\001\107\001\108\001\109\001\
\110\001\111\001\112\001\255\255\255\255\255\255\116\001\117\001\
\000\001\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\053\001\054\001\055\001\
\255\255\069\001\058\001\059\001\255\255\255\255\062\001\063\001\
\076\001\077\001\255\255\067\001\068\001\255\255\070\001\071\001\
\072\001\255\255\255\255\255\255\076\001\255\255\255\255\255\255\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\087\001\
\088\001\089\001\090\001\091\001\255\255\255\255\255\255\095\001\
\096\001\097\001\098\001\099\001\100\001\113\001\102\001\255\255\
\255\255\255\255\106\001\107\001\108\001\109\001\110\001\111\001\
\112\001\255\255\255\255\255\255\116\001\117\001\000\001\001\001\
\002\001\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\255\255\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\053\001\054\001\055\001\255\255\069\001\
\058\001\059\001\255\255\255\255\062\001\063\001\076\001\077\001\
\255\255\067\001\068\001\255\255\070\001\071\001\072\001\255\255\
\255\255\255\255\076\001\255\255\255\255\255\255\080\001\081\001\
\082\001\083\001\084\001\085\001\086\001\087\001\088\001\089\001\
\090\001\091\001\255\255\255\255\255\255\095\001\096\001\097\001\
\098\001\099\001\100\001\113\001\102\001\255\255\255\255\255\255\
\106\001\107\001\108\001\109\001\110\001\111\001\112\001\255\255\
\255\255\255\255\116\001\117\001\000\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\255\255\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\255\255\255\255\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\053\001\054\001\055\001\255\255\069\001\058\001\059\001\
\255\255\255\255\062\001\063\001\076\001\077\001\255\255\067\001\
\068\001\255\255\070\001\255\255\072\001\255\255\255\255\255\255\
\076\001\255\255\255\255\255\255\080\001\081\001\082\001\083\001\
\084\001\085\001\086\001\087\001\088\001\089\001\090\001\091\001\
\255\255\255\255\255\255\095\001\096\001\097\001\098\001\099\001\
\100\001\113\001\102\001\255\255\255\255\255\255\106\001\107\001\
\108\001\109\001\110\001\111\001\112\001\255\255\255\255\255\255\
\116\001\117\001\000\001\001\001\002\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\255\255\047\001\048\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\053\001\
\054\001\055\001\255\255\069\001\058\001\059\001\255\255\255\255\
\062\001\063\001\076\001\077\001\255\255\067\001\068\001\255\255\
\070\001\255\255\072\001\059\001\060\001\061\001\255\255\063\001\
\064\001\255\255\255\255\255\255\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\255\255\095\001\096\001\255\255\098\001\099\001\100\001\113\001\
\102\001\255\255\255\255\255\255\106\001\107\001\108\001\255\255\
\110\001\255\255\255\255\255\255\255\255\255\255\116\001\117\001\
\000\001\001\001\002\001\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\013\001\014\001\255\255\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\255\255\047\001\048\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\053\001\054\001\055\001\
\255\255\069\001\058\001\059\001\255\255\255\255\062\001\063\001\
\076\001\077\001\255\255\067\001\068\001\255\255\070\001\000\001\
\001\001\002\001\003\001\004\001\005\001\064\001\007\001\008\001\
\255\255\255\255\069\001\255\255\071\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\255\255\255\255\095\001\
\096\001\255\255\098\001\099\001\100\001\113\001\102\001\032\001\
\033\001\255\255\106\001\107\001\108\001\255\255\110\001\060\001\
\255\255\255\255\063\001\064\001\116\001\117\001\255\255\255\255\
\069\001\255\255\255\255\255\255\053\001\054\001\055\001\076\001\
\077\001\058\001\059\001\063\001\064\001\062\001\063\001\255\255\
\255\255\069\001\067\001\068\001\255\255\070\001\255\255\072\001\
\076\001\077\001\255\255\076\001\255\255\255\255\255\255\080\001\
\081\001\082\001\083\001\084\001\085\001\086\001\087\001\088\001\
\089\001\090\001\091\001\255\255\113\001\255\255\255\255\255\255\
\097\001\255\255\099\001\100\001\255\255\102\001\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\113\001\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\255\255\255\255\063\001\
\064\001\255\255\255\255\063\001\064\001\069\001\255\255\255\255\
\255\255\069\001\255\255\071\001\076\001\077\001\074\001\075\001\
\076\001\077\001\078\001\079\001\032\001\033\001\001\001\255\255\
\255\255\004\001\255\255\006\001\007\001\255\255\255\255\255\255\
\255\255\255\255\046\001\255\255\255\255\255\255\255\255\255\255\
\255\255\053\001\054\001\055\001\255\255\024\001\058\001\059\001\
\027\001\113\001\062\001\063\001\255\255\032\001\033\001\067\001\
\068\001\255\255\070\001\255\255\072\001\073\001\255\255\255\255\
\000\001\001\001\002\001\003\001\004\001\005\001\255\255\007\001\
\008\001\255\255\053\001\054\001\055\001\255\255\255\255\058\001\
\059\001\255\255\255\255\062\001\255\255\255\255\255\255\099\001\
\100\001\255\255\102\001\070\001\255\255\255\255\106\001\107\001\
\032\001\033\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\117\001\118\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\053\001\054\001\055\001\
\099\001\100\001\058\001\059\001\255\255\255\255\062\001\063\001\
\255\255\255\255\255\255\067\001\068\001\255\255\070\001\255\255\
\255\255\255\255\255\255\255\255\076\001\000\001\001\001\002\001\
\003\001\004\001\005\001\064\001\007\001\008\001\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\099\001\100\001\255\255\102\001\255\255\
\255\255\255\255\106\001\107\001\255\255\032\001\033\001\255\255\
\063\001\064\001\255\255\255\255\255\255\117\001\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\255\255\053\001\054\001\055\001\255\255\255\255\058\001\
\059\001\255\255\255\255\062\001\063\001\255\255\255\255\255\255\
\067\001\068\001\255\255\070\001\255\255\255\255\255\255\074\001\
\255\255\000\001\001\001\002\001\003\001\004\001\005\001\255\255\
\007\001\008\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\255\255\255\255\255\255\
\099\001\100\001\255\255\102\001\255\255\255\255\255\255\106\001\
\107\001\032\001\033\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\117\001\106\001\107\001\108\001\109\001\110\001\
\111\001\112\001\113\001\114\001\115\001\116\001\053\001\054\001\
\055\001\255\255\255\255\058\001\059\001\255\255\255\255\062\001\
\063\001\255\255\255\255\255\255\067\001\068\001\255\255\070\001\
\000\001\001\001\002\001\003\001\004\001\005\001\255\255\007\001\
\008\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\000\001\001\001\002\001\003\001\004\001\
\005\001\255\255\007\001\008\001\099\001\100\001\255\255\102\001\
\032\001\033\001\255\255\106\001\107\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\117\001\255\255\
\255\255\255\255\255\255\032\001\033\001\053\001\054\001\055\001\
\255\255\255\255\058\001\059\001\255\255\255\255\062\001\063\001\
\255\255\255\255\255\255\067\001\068\001\255\255\070\001\255\255\
\053\001\054\001\055\001\255\255\255\255\058\001\059\001\255\255\
\255\255\062\001\063\001\255\255\255\255\255\255\067\001\068\001\
\255\255\070\001\000\001\001\001\002\001\003\001\004\001\005\001\
\255\255\007\001\008\001\099\001\100\001\255\255\102\001\255\255\
\255\255\255\255\106\001\107\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\117\001\099\001\100\001\
\255\255\102\001\032\001\033\001\255\255\106\001\107\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\117\001\255\255\255\255\255\255\255\255\255\255\255\255\053\001\
\054\001\055\001\255\255\255\255\058\001\059\001\255\255\255\255\
\062\001\063\001\255\255\255\255\255\255\067\001\068\001\255\255\
\070\001\000\001\001\001\002\001\003\001\004\001\005\001\060\001\
\007\001\008\001\063\001\064\001\255\255\255\255\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\255\255\255\255\099\001\100\001\255\255\
\102\001\032\001\033\001\255\255\106\001\107\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\117\001\
\255\255\255\255\255\255\255\255\255\255\255\255\053\001\054\001\
\055\001\255\255\255\255\058\001\059\001\255\255\255\255\062\001\
\063\001\255\255\255\255\255\255\067\001\068\001\255\255\070\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\047\001\048\001\049\001\050\001\051\001\052\001\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\099\001\100\001\255\255\102\001\
\069\001\255\255\071\001\106\001\107\001\074\001\075\001\076\001\
\077\001\078\001\079\001\255\255\255\255\255\255\117\001\001\001\
\002\001\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\053\001\054\001\055\001\255\255\255\255\
\058\001\059\001\255\255\255\255\062\001\063\001\255\255\255\255\
\255\255\067\001\068\001\255\255\070\001\255\255\255\255\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\095\001\096\001\069\001\
\098\001\099\001\100\001\255\255\102\001\255\255\076\001\077\001\
\106\001\107\001\108\001\000\001\110\001\255\255\255\255\255\255\
\255\255\006\001\116\001\117\001\009\001\010\001\011\001\012\001\
\013\001\014\001\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\113\001\060\001\061\001\255\255\063\001\
\064\001\255\255\255\255\255\255\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\255\255\255\255\255\255\255\255\047\001\048\001\255\255\255\255\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\059\001\060\001\061\001\255\255\063\001\064\001\255\255\076\001\
\255\255\255\255\069\001\255\255\071\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\255\255\255\255\032\001\
\033\001\034\001\095\001\096\001\255\255\098\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\108\001\
\255\255\110\001\111\001\112\001\053\001\054\001\055\001\116\001\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\072\001\
\001\001\002\001\003\001\004\001\005\001\060\001\007\001\008\001\
\063\001\064\001\255\255\255\255\255\255\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\255\255\099\001\100\001\255\255\102\001\255\255\032\001\
\033\001\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\072\001\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\099\001\100\001\255\255\102\001\255\255\032\001\
\033\001\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\072\001\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\099\001\100\001\255\255\102\001\255\255\032\001\
\033\001\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\072\001\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\099\001\100\001\255\255\102\001\255\255\032\001\
\033\001\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\001\001\
\002\001\003\001\004\001\005\001\255\255\007\001\008\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\001\001\002\001\003\001\004\001\005\001\255\255\
\007\001\008\001\099\001\100\001\255\255\102\001\032\001\033\001\
\255\255\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\255\255\255\255\255\255\
\255\255\032\001\033\001\053\001\054\001\055\001\255\255\255\255\
\058\001\059\001\255\255\255\255\062\001\063\001\255\255\255\255\
\255\255\067\001\068\001\255\255\070\001\255\255\053\001\054\001\
\055\001\255\255\255\255\058\001\059\001\255\255\255\255\062\001\
\063\001\255\255\255\255\255\255\067\001\068\001\255\255\070\001\
\255\255\001\001\002\001\003\001\004\001\005\001\255\255\007\001\
\008\001\099\001\100\001\255\255\102\001\255\255\255\255\255\255\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\117\001\099\001\100\001\255\255\102\001\
\032\001\033\001\255\255\106\001\107\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\117\001\255\255\
\255\255\255\255\255\255\255\255\255\255\053\001\054\001\055\001\
\255\255\255\255\058\001\059\001\255\255\255\255\062\001\063\001\
\255\255\255\255\255\255\067\001\068\001\255\255\070\001\255\255\
\001\001\002\001\003\001\004\001\005\001\255\255\007\001\008\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\001\001\002\001\003\001\004\001\005\001\
\255\255\007\001\008\001\099\001\100\001\255\255\102\001\032\001\
\033\001\255\255\106\001\107\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\117\001\255\255\255\255\
\255\255\255\255\032\001\033\001\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\063\001\255\255\
\255\255\255\255\067\001\068\001\255\255\070\001\255\255\053\001\
\054\001\055\001\255\255\255\255\058\001\059\001\255\255\255\255\
\062\001\063\001\255\255\255\255\255\255\067\001\068\001\255\255\
\070\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\099\001\100\001\255\255\102\001\255\255\255\255\
\255\255\106\001\107\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\117\001\099\001\100\001\255\255\
\102\001\001\001\255\255\255\255\106\001\107\001\006\001\255\255\
\255\255\009\001\010\001\011\001\012\001\013\001\014\001\117\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\001\001\255\255\255\255\255\255\255\255\006\001\255\255\255\255\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\047\001\048\001\
\049\001\050\001\051\001\052\001\076\001\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\255\255\095\001\
\096\001\097\001\098\001\076\001\077\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\108\001\255\255\110\001\111\001\
\112\001\255\255\114\001\115\001\116\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\095\001\096\001\
\097\001\098\001\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\255\255\108\001\255\255\110\001\111\001\112\001\
\255\255\114\001\115\001\116\001\006\001\255\255\255\255\009\001\
\010\001\011\001\012\001\013\001\014\001\255\255\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\255\255\255\255\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\065\001\
\066\001\067\001\068\001\069\001\070\001\071\001\072\001\073\001\
\074\001\075\001\076\001\077\001\078\001\079\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\095\001\096\001\255\255\
\098\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\108\001\255\255\110\001\255\255\255\255\113\001\
\006\001\007\001\116\001\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\255\255\006\001\255\255\255\255\009\001\010\001\
\011\001\012\001\013\001\014\001\255\255\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\031\001\255\255\255\255\255\255\
\255\255\006\001\255\255\255\255\009\001\010\001\011\001\012\001\
\013\001\014\001\255\255\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\255\255\255\255\255\255\255\255\255\255\
\255\255\095\001\096\001\070\001\098\001\099\001\100\001\255\255\
\255\255\255\255\255\255\078\001\255\255\255\255\108\001\255\255\
\110\001\255\255\255\255\255\255\255\255\255\255\116\001\047\001\
\048\001\255\255\255\255\255\255\095\001\096\001\255\255\098\001\
\069\001\070\001\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\108\001\255\255\110\001\255\255\069\001\255\255\071\001\
\255\255\116\001\074\001\075\001\076\001\077\001\078\001\079\001\
\255\255\255\255\095\001\096\001\255\255\098\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\108\001\
\255\255\110\001\255\255\255\255\255\255\006\001\255\255\116\001\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\255\255\
\006\001\255\255\255\255\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\255\255\255\255\006\001\255\255\255\255\009\001\
\010\001\011\001\012\001\013\001\014\001\070\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\095\001\096\001\
\255\255\098\001\072\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\108\001\255\255\110\001\255\255\255\255\
\255\255\255\255\255\255\116\001\255\255\255\255\255\255\255\255\
\255\255\095\001\096\001\255\255\098\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\078\001\255\255\108\001\255\255\
\110\001\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\255\255\255\255\255\255\255\255\255\255\095\001\096\001\255\255\
\098\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\108\001\255\255\110\001\255\255\255\255\255\255\
\006\001\255\255\116\001\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\009\001\010\001\011\001\012\001\013\001\014\001\
\255\255\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\000\001\001\001\255\255\255\255\004\001\255\255\006\001\007\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\024\001\095\001\096\001\027\001\098\001\255\255\255\255\255\255\
\032\001\033\001\255\255\255\255\255\255\255\255\108\001\255\255\
\110\001\255\255\255\255\255\255\255\255\255\255\116\001\255\255\
\095\001\096\001\255\255\098\001\255\255\053\001\054\001\055\001\
\255\255\255\255\058\001\059\001\255\255\108\001\062\001\110\001\
\255\255\255\255\255\255\255\255\255\255\116\001\070\001\000\001\
\001\001\255\255\255\255\004\001\255\255\006\001\007\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\024\001\
\255\255\255\255\027\001\099\001\100\001\255\255\255\255\032\001\
\033\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\055\001\255\255\
\255\255\058\001\059\001\255\255\255\255\062\001\047\001\048\001\
\049\001\050\001\051\001\052\001\255\255\070\001\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\086\001\255\255\255\255\
\255\255\255\255\255\255\076\001\077\001\255\255\255\255\255\255\
\255\255\255\255\099\001\100\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\059\001\060\001\061\001\
\113\001\063\001\064\001\065\001\066\001\067\001\068\001\069\001\
\070\001\071\001\255\255\073\001\074\001\075\001\076\001\077\001\
\078\001\079\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\255\255\255\255\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\113\001\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\255\255\255\255\047\001\048\001\049\001\
\050\001\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\065\001\
\066\001\113\001\255\255\069\001\255\255\071\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\255\255\255\255\047\001\048\001\049\001\050\001\051\001\
\052\001\053\001\054\001\055\001\056\001\057\001\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\065\001\066\001\113\001\
\255\255\069\001\255\255\071\001\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\079\001\047\001\048\001\049\001\050\001\
\051\001\052\001\053\001\054\001\055\001\056\001\057\001\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\065\001\066\001\
\255\255\255\255\069\001\255\255\255\255\255\255\255\255\255\255\
\255\255\076\001\077\001\255\255\255\255\113\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\065\001\066\001\255\255\255\255\069\001\255\255\255\255\255\255\
\255\255\255\255\255\255\076\001\077\001\255\255\113\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\255\255\255\255\069\001\255\255\255\255\
\255\255\255\255\255\255\255\255\076\001\077\001\255\255\255\255\
\113\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\255\255\255\255\255\255\255\255\255\255\076\001\077\001\
\255\255\113\001\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\054\001\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\065\001\066\001\255\255\255\255\
\069\001\047\001\048\001\049\001\050\001\051\001\052\001\076\001\
\077\001\255\255\255\255\113\001\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\255\255\255\255\255\255\255\255\255\255\076\001\077\001\
\255\255\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\113\001\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\071\001\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\113\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\067\001\068\001\255\255\
\070\001\071\001\255\255\073\001\255\255\075\001\255\255\077\001\
\255\255\079\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\065\001\066\001\067\001\068\001\255\255\070\001\255\255\
\255\255\073\001\255\255\255\255\076\001\077\001\255\255\079\001\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\065\001\066\001\255\255\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\047\001\048\001\049\001\050\001\051\001\052\001\053\001\
\054\001\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\065\001\066\001\255\255\255\255\069\001\
\255\255\071\001\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\047\001\048\001\049\001\050\001\051\001\052\001\
\053\001\054\001\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\065\001\066\001\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\047\001\048\001\049\001\050\001\051\001\
\052\001\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\063\001\064\001\065\001\066\001\255\255\
\255\255\069\001\255\255\071\001\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\079\001\047\001\048\001\049\001\050\001\
\051\001\052\001\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\063\001\064\001\065\001\066\001\
\255\255\255\255\069\001\255\255\071\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\047\001\048\001\049\001\
\050\001\051\001\052\001\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\063\001\064\001\065\001\
\066\001\255\255\255\255\069\001\255\255\071\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\047\001\048\001\
\049\001\050\001\051\001\052\001\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\063\001\064\001\
\255\255\255\255\255\255\255\255\069\001\255\255\071\001\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\047\001\
\048\001\049\001\050\001\051\001\052\001\255\255\255\255\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\063\001\
\064\001\255\255\255\255\255\255\255\255\069\001\255\255\071\001\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\047\001\048\001\049\001\050\001\051\001\052\001\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\063\001\064\001\255\255\255\255\255\255\255\255\069\001\255\255\
\071\001\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\047\001\048\001\049\001\050\001\051\001\052\001\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\063\001\064\001\255\255\255\255\255\255\255\255\069\001\
\255\255\071\001\047\001\048\001\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\063\001\064\001\255\255\255\255\255\255\255\255\
\069\001\255\255\071\001\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BUILTIN_VA_LIST\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  AT_NAME\000\
  "

let yynames_block = "\
  IDENT\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  CHAR\000\
  INT\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  INT32\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  THREAD\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  ATTRIBUTE_USED\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA_LINE\000\
  PRAGMA\000\
  AT_TRANSFORM\000\
  AT_TRANSFORMEXPR\000\
  AT_SPECIFIER\000\
  AT_EXPR\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.definition list) in
    Obj.repr(
# 397 "src/frontc/cparser.mly"
              (_1)
# 2309 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 399 "src/frontc/cparser.mly"
                 (_1)
# 2316 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun parser_env ->
    Obj.repr(
# 402 "src/frontc/cparser.mly"
                                        ( [] )
# 2322 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.definition) in
    let _2 = (peek_val parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 403 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 2330 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.definition list) in
    Obj.repr(
# 404 "src/frontc/cparser.mly"
                                        ( _2 )
# 2338 "src/frontc/cparser.ml"
               : Cabs.definition list))
; (fun parser_env ->
    Obj.repr(
# 408 "src/frontc/cparser.mly"
                               ( currentLoc () )
# 2344 "src/frontc/cparser.ml"
               : Cabs.cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.definition) in
    Obj.repr(
# 413 "src/frontc/cparser.mly"
                                        ( _1 )
# 2351 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.definition) in
    Obj.repr(
# 414 "src/frontc/cparser.mly"
                                        ( _1 )
# 2358 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : string * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.definition) in
    Obj.repr(
# 417 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, (*handleLoc*) (snd _2), [ _3 ]) )
# 2367 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : string * cabsloc) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.definition list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 419 "src/frontc/cparser.mly"
                                        ( LINKAGE (fst _2, (*handleLoc*) (snd _2), _4)  )
# 2378 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 2 : string * cabsloc) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 421 "src/frontc/cparser.mly"
                                        ( GLOBASM (fst _3, (*handleLoc*) _1) )
# 2388 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'pragma) in
    Obj.repr(
# 422 "src/frontc/cparser.mly"
                                        ( _1 )
# 2395 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 3 : string list) in
    let _5 = (peek_val parser_env 1 : 'old_pardef_list) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 427 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in 
                             (* Make the function declarator *)
                             doDeclaration ((*handleLoc*) (snd _1)) []
                               [((fst _1, PROTO(JUSTBASE, pardecl,isva), [], cabslu),
                                 NO_INIT)]
                            )
# 2412 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 436 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             doDeclaration ((*handleLoc*)(snd _1)) []
                               [((fst _1, PROTO(JUSTBASE,[],false), [], cabslu),
                                 NO_INIT)]
                            )
# 2425 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 7 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 6 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 5 : Cabs.definition) in
    let _4 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _7 = (peek_val parser_env 1 : Cabs.definition list) in
    let _8 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 442 "src/frontc/cparser.mly"
                                                                        (
    checkConnective(fst _5);
    TRANSFORMER(_3, _7, _1)
  )
# 2442 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 7 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 6 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 5 : Cabs.expression * cabsloc) in
    let _4 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 3 : string * Cabs.cabsloc) in
    let _6 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _7 = (peek_val parser_env 1 : Cabs.expression * cabsloc) in
    let _8 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 447 "src/frontc/cparser.mly"
                                                                                   (
    checkConnective(fst _5);
    EXPRTRANSFORMER(fst _3, fst _7, _1)
  )
# 2459 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 451 "src/frontc/cparser.mly"
                           ( PRAGMA (VARIABLE "parse_error", _1) )
# 2467 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 455 "src/frontc/cparser.mly"
             (fst _1)
# 2474 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 456 "src/frontc/cparser.mly"
                  (fst _1)
# 2481 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 457 "src/frontc/cparser.mly"
                                        ( "@name(" ^ fst _3 ^ ")" )
# 2489 "src/frontc/cparser.ml"
               : 'id_or_typename))
; (fun parser_env ->
    Obj.repr(
# 461 "src/frontc/cparser.mly"
                                        ( () )
# 2495 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun parser_env ->
    Obj.repr(
# 462 "src/frontc/cparser.mly"
                                        ( () )
# 2501 "src/frontc/cparser.ml"
               : 'maybecomma))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 469 "src/frontc/cparser.mly"
          (VARIABLE (fst _1), snd _1)
# 2508 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 471 "src/frontc/cparser.mly"
          (CONSTANT (fst _1), snd _1)
# 2515 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 473 "src/frontc/cparser.mly"
          (smooth_expression (fst _1), snd _1)
# 2522 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 475 "src/frontc/cparser.mly"
          ( GNU_BODY (fst3 _2), _1 )
# 2530 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 479 "src/frontc/cparser.mly"
                         ( EXPR_PATTERN(fst _3), _1 )
# 2539 "src/frontc/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'primary_expression) in
    Obj.repr(
# 484 "src/frontc/cparser.mly"
                        ( _1 )
# 2546 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'postfix_expression) in
    let _2 = (peek_val parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 486 "src/frontc/cparser.mly"
   (INDEX (fst _1, smooth_expression _2), snd _1)
# 2554 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'postfix_expression) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 488 "src/frontc/cparser.mly"
   (CALL (fst _1, _3), snd _1)
# 2563 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 3 : Cabs.expression * cabsloc) in
    let _5 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 490 "src/frontc/cparser.mly"
                        ( let b, d = _5 in
                          CALL (VARIABLE "__builtin_va_arg", 
                                [fst _3; TYPE_SIZEOF (b, d)]), _1 )
# 2575 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 494 "src/frontc/cparser.mly"
                        ( let b1,d1 = _3 in
                          let b2,d2 = _5 in
                          CALL (VARIABLE "__builtin_types_compatible_p", 
                                [TYPE_SIZEOF(b1,d1); TYPE_SIZEOF(b2,d2)]), _1 )
# 2588 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (peek_val parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 499 "src/frontc/cparser.mly"
                        ( transformOffsetOf _3 (fst _5), _1 )
# 2598 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_expression) in
    let _3 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 501 "src/frontc/cparser.mly"
          (MEMBEROF (fst _1, _3), snd _1)
# 2606 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_expression) in
    let _3 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 503 "src/frontc/cparser.mly"
          (MEMBEROFPTR (fst _1, _3), snd _1)
# 2614 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'postfix_expression) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 505 "src/frontc/cparser.mly"
          (UNARY (POSINCR, fst _1), snd _1)
# 2622 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'postfix_expression) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 507 "src/frontc/cparser.mly"
          (UNARY (POSDECR, fst _1), snd _1)
# 2630 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 1 : 'initializer_list_opt) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 510 "src/frontc/cparser.mly"
          ( CAST(_2, COMPOUND_INIT _5), _1 )
# 2641 "src/frontc/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 515 "src/frontc/cparser.mly"
          ( VARIABLE (fst _1), snd _1 )
# 2648 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'offsetof_member_designator) in
    let _3 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 517 "src/frontc/cparser.mly"
   ( MEMBEROF (fst _1, fst _3), snd _1 )
# 2656 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'offsetof_member_designator) in
    let _2 = (peek_val parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 519 "src/frontc/cparser.mly"
   ( INDEX (fst _1, smooth_expression _2), snd _1 )
# 2664 "src/frontc/cparser.ml"
               : 'offsetof_member_designator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 524 "src/frontc/cparser.mly"
                        ( _1 )
# 2671 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 526 "src/frontc/cparser.mly"
          (UNARY (PREINCR, fst _2), _1)
# 2679 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 528 "src/frontc/cparser.mly"
          (UNARY (PREDECR, fst _2), _1)
# 2687 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 530 "src/frontc/cparser.mly"
          (EXPR_SIZEOF (fst _2), _1)
# 2695 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 532 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_SIZEOF (b, d), _1)
# 2704 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 534 "src/frontc/cparser.mly"
          (EXPR_ALIGNOF (fst _2), _1)
# 2712 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 536 "src/frontc/cparser.mly"
          (let b, d = _3 in TYPE_ALIGNOF (b, d), _1)
# 2721 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 538 "src/frontc/cparser.mly"
          (UNARY (PLUS, fst _2), _1)
# 2729 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 540 "src/frontc/cparser.mly"
          (UNARY (MINUS, fst _2), _1)
# 2737 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 542 "src/frontc/cparser.mly"
          (UNARY (MEMOF, fst _2), _1)
# 2745 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 544 "src/frontc/cparser.mly"
          (UNARY (ADDROF, fst _2), _1)
# 2753 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 546 "src/frontc/cparser.mly"
          (UNARY (NOT, fst _2), _1)
# 2761 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 548 "src/frontc/cparser.mly"
          (UNARY (BNOT, fst _2), _1)
# 2769 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 549 "src/frontc/cparser.mly"
                               ( LABELADDR (fst _2), _1 )
# 2777 "src/frontc/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 554 "src/frontc/cparser.mly"
                         ( _1 )
# 2784 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 556 "src/frontc/cparser.mly"
           ( CAST(_2, SINGLE_INIT (fst _4)), _1 )
# 2793 "src/frontc/cparser.ml"
               : 'cast_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 561 "src/frontc/cparser.mly"
                         ( _1 )
# 2800 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 563 "src/frontc/cparser.mly"
   (BINARY(MUL, fst _1, fst _3), snd _1)
# 2809 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 565 "src/frontc/cparser.mly"
   (BINARY(DIV, fst _1, fst _3), snd _1)
# 2817 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 567 "src/frontc/cparser.mly"
   (BINARY(MOD, fst _1, fst _3), snd _1)
# 2825 "src/frontc/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 572 "src/frontc/cparser.mly"
                        ( _1 )
# 2832 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_expression) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 574 "src/frontc/cparser.mly"
   (BINARY(ADD, fst _1, fst _3), snd _1)
# 2841 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_expression) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 576 "src/frontc/cparser.mly"
   (BINARY(SUB, fst _1, fst _3), snd _1)
# 2850 "src/frontc/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 581 "src/frontc/cparser.mly"
                         ( _1 )
# 2857 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_expression) in
    let _3 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 583 "src/frontc/cparser.mly"
   (BINARY(SHL, fst _1, fst _3), snd _1)
# 2865 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_expression) in
    let _3 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 585 "src/frontc/cparser.mly"
   (BINARY(SHR, fst _1, fst _3), snd _1)
# 2873 "src/frontc/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 591 "src/frontc/cparser.mly"
                        ( _1 )
# 2880 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 593 "src/frontc/cparser.mly"
   (BINARY(LT, fst _1, fst _3), snd _1)
# 2888 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 595 "src/frontc/cparser.mly"
   (BINARY(GT, fst _1, fst _3), snd _1)
# 2896 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 597 "src/frontc/cparser.mly"
   (BINARY(LE, fst _1, fst _3), snd _1)
# 2904 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 599 "src/frontc/cparser.mly"
   (BINARY(GE, fst _1, fst _3), snd _1)
# 2912 "src/frontc/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 604 "src/frontc/cparser.mly"
                        ( _1 )
# 2919 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_expression) in
    let _3 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 606 "src/frontc/cparser.mly"
   (BINARY(EQ, fst _1, fst _3), snd _1)
# 2927 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_expression) in
    let _3 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 608 "src/frontc/cparser.mly"
   (BINARY(NE, fst _1, fst _3), snd _1)
# 2935 "src/frontc/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'equality_expression) in
    Obj.repr(
# 614 "src/frontc/cparser.mly"
                       ( _1 )
# 2942 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_and_expression) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'equality_expression) in
    Obj.repr(
# 616 "src/frontc/cparser.mly"
   (BINARY(BAND, fst _1, fst _3), snd _1)
# 2951 "src/frontc/cparser.ml"
               : 'bitwise_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 621 "src/frontc/cparser.mly"
                       ( _1 )
# 2958 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (peek_val parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 623 "src/frontc/cparser.mly"
   (BINARY(XOR, fst _1, fst _3), snd _1)
# 2966 "src/frontc/cparser.ml"
               : 'bitwise_xor_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 628 "src/frontc/cparser.mly"
                        ( _1 )
# 2973 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_or_expression) in
    let _3 = (peek_val parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 630 "src/frontc/cparser.mly"
   (BINARY(BOR, fst _1, fst _3), snd _1)
# 2981 "src/frontc/cparser.ml"
               : 'bitwise_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 635 "src/frontc/cparser.mly"
                        ( _1 )
# 2988 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_and_expression) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 637 "src/frontc/cparser.mly"
   (BINARY(AND, fst _1, fst _3), snd _1)
# 2997 "src/frontc/cparser.ml"
               : 'logical_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 642 "src/frontc/cparser.mly"
                        ( _1 )
# 3004 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_or_expression) in
    let _3 = (peek_val parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 644 "src/frontc/cparser.mly"
   (BINARY(OR, fst _1, fst _3), snd _1)
# 3012 "src/frontc/cparser.ml"
               : 'logical_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 649 "src/frontc/cparser.mly"
                         ( _1 )
# 3019 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'logical_or_expression) in
    let _3 = (peek_val parser_env 2 : Cabs.expression) in
    let _5 = (peek_val parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 651 "src/frontc/cparser.mly"
   (QUESTION (fst _1, _3, fst _5), snd _1)
# 3028 "src/frontc/cparser.ml"
               : 'conditional_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 659 "src/frontc/cparser.mly"
                         ( _1 )
# 3035 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 661 "src/frontc/cparser.mly"
   (BINARY(ASSIGN, fst _1, fst _3), snd _1)
# 3043 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 663 "src/frontc/cparser.mly"
   (BINARY(ADD_ASSIGN, fst _1, fst _3), snd _1)
# 3051 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 665 "src/frontc/cparser.mly"
   (BINARY(SUB_ASSIGN, fst _1, fst _3), snd _1)
# 3059 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 667 "src/frontc/cparser.mly"
   (BINARY(MUL_ASSIGN, fst _1, fst _3), snd _1)
# 3067 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 669 "src/frontc/cparser.mly"
   (BINARY(DIV_ASSIGN, fst _1, fst _3), snd _1)
# 3075 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 671 "src/frontc/cparser.mly"
   (BINARY(MOD_ASSIGN, fst _1, fst _3), snd _1)
# 3083 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 673 "src/frontc/cparser.mly"
   (BINARY(BAND_ASSIGN, fst _1, fst _3), snd _1)
# 3091 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 675 "src/frontc/cparser.mly"
   (BINARY(BOR_ASSIGN, fst _1, fst _3), snd _1)
# 3099 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 677 "src/frontc/cparser.mly"
   (BINARY(XOR_ASSIGN, fst _1, fst _3), snd _1)
# 3107 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 679 "src/frontc/cparser.mly"
   (BINARY(SHL_ASSIGN, fst _1, fst _3), snd _1)
# 3115 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'cast_expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 681 "src/frontc/cparser.mly"
   (BINARY(SHR_ASSIGN, fst _1, fst _3), snd _1)
# 3123 "src/frontc/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 686 "src/frontc/cparser.mly"
                        ( _1 )
# 3130 "src/frontc/cparser.ml"
               : Cabs.expression * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 691 "src/frontc/cparser.mly"
               (CONST_INT (fst _1), snd _1)
# 3137 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 692 "src/frontc/cparser.mly"
                 (CONST_FLOAT (fst _1), snd _1)
# 3144 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 693 "src/frontc/cparser.mly"
                (CONST_CHAR (fst _1), snd _1)
# 3151 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 694 "src/frontc/cparser.mly"
                 (CONST_WCHAR (fst _1), snd _1)
# 3158 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * cabsloc) in
    Obj.repr(
# 695 "src/frontc/cparser.mly"
                             (CONST_STRING (fst _1), snd _1)
# 3165 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 696 "src/frontc/cparser.mly"
                   (CONST_WSTRING (fst _1), snd _1)
# 3172 "src/frontc/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list Queue.t * cabsloc) in
    Obj.repr(
# 702 "src/frontc/cparser.mly"
                                        (
     let queue, location = _1 in
     let buffer = Buffer.create (Queue.length queue) in
     Queue.iter
       (List.iter
	  (fun value ->
	    let char = int64_to_char value in
	    Buffer.add_char buffer char))
       queue;
     Buffer.contents buffer, location
   )
# 3189 "src/frontc/cparser.ml"
               : string * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 716 "src/frontc/cparser.mly"
                                        (intlist_to_string (fst _1) )
# 3196 "src/frontc/cparser.ml"
               : 'one_string_constant))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'one_string) in
    Obj.repr(
# 719 "src/frontc/cparser.mly"
                                        (
      let queue = Queue.create () in
      Queue.add (fst _1) queue;
      queue, snd _1
    )
# 3207 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : int64 list Queue.t * cabsloc) in
    let _2 = (peek_val parser_env 0 : 'one_string) in
    Obj.repr(
# 724 "src/frontc/cparser.mly"
                                        (
      Queue.add (fst _2) (fst _1);
      _1
    )
# 3218 "src/frontc/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 731 "src/frontc/cparser.mly"
                                        ( _1 )
# 3225 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : int64 list * cabsloc) in
    let _2 = (peek_val parser_env 0 : 'one_string) in
    Obj.repr(
# 732 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3233 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : int64 list * cabsloc) in
    let _2 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 733 "src/frontc/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3241 "src/frontc/cparser.ml"
               : int64 list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 738 "src/frontc/cparser.mly"
                  (_1)
# 3248 "src/frontc/cparser.ml"
               : 'one_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 739 "src/frontc/cparser.mly"
                                        ((Cabs.explodeStringToInts 
					    !currentFunctionName), _1)
# 3256 "src/frontc/cparser.ml"
               : 'one_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 741 "src/frontc/cparser.mly"
                                        ((Cabs.explodeStringToInts 
					    !currentFunctionName), _1)
# 3264 "src/frontc/cparser.ml"
               : 'one_string))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 746 "src/frontc/cparser.mly"
                        ( SINGLE_INIT (fst _1) )
# 3271 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : 'initializer_list_opt) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 748 "src/frontc/cparser.mly"
   ( COMPOUND_INIT _2)
# 3280 "src/frontc/cparser.ml"
               : Cabs.init_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 751 "src/frontc/cparser.mly"
                                            ( [_1] )
# 3287 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (peek_val parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 752 "src/frontc/cparser.mly"
                                            ( _1 :: _3 )
# 3295 "src/frontc/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun parser_env ->
    Obj.repr(
# 755 "src/frontc/cparser.mly"
                                            ( [] )
# 3301 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 756 "src/frontc/cparser.mly"
                                            ( _1 )
# 3308 "src/frontc/cparser.ml"
               : 'initializer_list_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.initwhat) in
    let _2 = (peek_val parser_env 1 : 'eq_opt) in
    let _3 = (peek_val parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 759 "src/frontc/cparser.mly"
                                            ( (_1, _3) )
# 3317 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'gcc_init_designators) in
    let _2 = (peek_val parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 760 "src/frontc/cparser.mly"
                                         ( (_1, _2) )
# 3325 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 761 "src/frontc/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 3332 "src/frontc/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun parser_env ->
    Obj.repr(
# 764 "src/frontc/cparser.mly"
                             ( () )
# 3338 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun parser_env ->
    Obj.repr(
# 766 "src/frontc/cparser.mly"
                                 ( () )
# 3344 "src/frontc/cparser.ml"
               : 'eq_opt))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'id_or_typename) in
    let _3 = (peek_val parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 769 "src/frontc/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 3352 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : Cabs.expression * cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 771 "src/frontc/cparser.mly"
                                        ( ATINDEX_INIT(fst _2, _4) )
# 3360 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : Cabs.expression * cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 773 "src/frontc/cparser.mly"
                                        ( ATINDEXRANGE_INIT(fst _2, fst _4) )
# 3368 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun parser_env ->
    Obj.repr(
# 776 "src/frontc/cparser.mly"
                                        ( NEXT_INIT )
# 3374 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 777 "src/frontc/cparser.mly"
                                        ( _1 )
# 3381 "src/frontc/cparser.ml"
               : Cabs.initwhat))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 781 "src/frontc/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 3388 "src/frontc/cparser.ml"
               : 'gcc_init_designators))
; (fun parser_env ->
    Obj.repr(
# 785 "src/frontc/cparser.mly"
                                    ( [] )
# 3394 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 786 "src/frontc/cparser.mly"
                                    ( fst _1 )
# 3401 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun parser_env ->
    Obj.repr(
# 791 "src/frontc/cparser.mly"
          (NOTHING)
# 3407 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 793 "src/frontc/cparser.mly"
          (smooth_expression (fst _1))
# 3414 "src/frontc/cparser.ml"
               : Cabs.expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 797 "src/frontc/cparser.mly"
                                           ([fst _1], snd _1)
# 3421 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.expression * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 798 "src/frontc/cparser.mly"
                                                  ( fst _1 :: fst _3, snd _1 )
# 3429 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun parser_env ->
    let _3 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 799 "src/frontc/cparser.mly"
                                                  ( _3 )
# 3436 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun parser_env ->
    Obj.repr(
# 803 "src/frontc/cparser.mly"
                                    ( NOTHING )
# 3442 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 804 "src/frontc/cparser.mly"
                                    ( smooth_expression (fst _1) )
# 3449 "src/frontc/cparser.ml"
               : 'comma_expression_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 808 "src/frontc/cparser.mly"
                                                   ( _2 )
# 3457 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 809 "src/frontc/cparser.mly"
                                                   ( [], _1 )
# 3464 "src/frontc/cparser.ml"
               : Cabs.expression list * cabsloc))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    Obj.repr(
# 813 "src/frontc/cparser.mly"
                                                       ( fst _2 )
# 3471 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun parser_env ->
    Obj.repr(
# 814 "src/frontc/cparser.mly"
                                                       ( [] )
# 3477 "src/frontc/cparser.ml"
               : Cabs.expression list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'block_begin) in
    let _2 = (peek_val parser_env 3 : string list) in
    let _3 = (peek_val parser_env 2 : 'block_attrs) in
    let _4 = (peek_val parser_env 1 : Cabs.statement list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 821 "src/frontc/cparser.mly"
                                         (!Lexerhack.pop_context();
                                          { blabels = _2;
                                            battrs = _3;
                                            bstmts = _4 },
					    _1, _5
                                         )
# 3493 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 827 "src/frontc/cparser.mly"
                                         ( { blabels = [];
                                             battrs  = [];
                                             bstmts  = [] },
					     _2, _3
                                         )
# 3505 "src/frontc/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 834 "src/frontc/cparser.mly"
                           (!Lexerhack.push_context (); _1)
# 3512 "src/frontc/cparser.ml"
               : 'block_begin))
; (fun parser_env ->
    Obj.repr(
# 838 "src/frontc/cparser.mly"
                                                            ( [] )
# 3518 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 840 "src/frontc/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 3525 "src/frontc/cparser.ml"
               : 'block_attrs))
; (fun parser_env ->
    Obj.repr(
# 845 "src/frontc/cparser.mly"
                                         ( [] )
# 3531 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.definition) in
    let _2 = (peek_val parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 846 "src/frontc/cparser.mly"
                                         ( DEFINITION(_1) :: _2 )
# 3539 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.statement) in
    let _2 = (peek_val parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 847 "src/frontc/cparser.mly"
                                         ( _1 :: _2 )
# 3547 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 849 "src/frontc/cparser.mly"
                                         ( [ LABEL (fst _1, NOP (snd _1), 
                                                    snd _1)] )
# 3555 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'pragma) in
    let _2 = (peek_val parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 851 "src/frontc/cparser.mly"
                                         ( _2 )
# 3563 "src/frontc/cparser.ml"
               : Cabs.statement list))
; (fun parser_env ->
    Obj.repr(
# 855 "src/frontc/cparser.mly"
                                                     ( [] )
# 3569 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : string list) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 856 "src/frontc/cparser.mly"
                                                     ( _2 @ _4 )
# 3578 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 859 "src/frontc/cparser.mly"
                                         ( [ fst _1 ] )
# 3585 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 860 "src/frontc/cparser.mly"
                                         ( fst _1 :: _3 )
# 3593 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 866 "src/frontc/cparser.mly"
               (NOP ((*handleLoc*) _1) )
# 3600 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 868 "src/frontc/cparser.mly"
          (COMPUTATION (smooth_expression (fst _1), (*handleLoc*)(snd _1)))
# 3608 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 869 "src/frontc/cparser.mly"
                        (BLOCK (fst3 _1, (*handleLoc*)(snd3 _1)))
# 3615 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 871 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, NOP _1, _1))
# 3624 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.expression list * cabsloc) in
    let _3 = (peek_val parser_env 2 : Cabs.statement) in
    let _5 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 873 "src/frontc/cparser.mly"
                 (IF (smooth_expression (fst _2), _3, _5, (*handleLoc*) _1))
# 3634 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 875 "src/frontc/cparser.mly"
                        (SWITCH (smooth_expression (fst _2), _3, (*handleLoc*) _1))
# 3643 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 877 "src/frontc/cparser.mly"
          (WHILE (smooth_expression (fst _2), _3, (*handleLoc*) _1))
# 3652 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.statement) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 879 "src/frontc/cparser.mly"
                   (DOWHILE (smooth_expression (fst _4), _2, (*handleLoc*) _1))
# 3663 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 7 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 6 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 5 : 'for_clause) in
    let _4 = (peek_val parser_env 4 : Cabs.expression) in
    let _5 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _6 = (peek_val parser_env 2 : Cabs.expression) in
    let _8 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 882 "src/frontc/cparser.mly"
                          (FOR (_3, _4, _6, _8, (*handleLoc*) _1))
# 3676 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 884 "src/frontc/cparser.mly"
                   (LABEL (fst _1, _3, (*handleLoc*) (snd _1)))
# 3684 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.expression * cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 886 "src/frontc/cparser.mly"
                          (CASE (fst _2, _4, (*handleLoc*) _1))
# 3693 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : Cabs.expression * cabsloc) in
    let _4 = (peek_val parser_env 2 : Cabs.expression * cabsloc) in
    let _6 = (peek_val parser_env 0 : Cabs.statement) in
    Obj.repr(
# 888 "src/frontc/cparser.mly"
                          (CASERANGE (fst _2, fst _4, _6, (*handleLoc*) _1))
# 3703 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 890 "src/frontc/cparser.mly"
                          (DEFAULT (NOP _1, (*handleLoc*) _1))
# 3710 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 891 "src/frontc/cparser.mly"
                       (RETURN (NOTHING, (*handleLoc*) _1))
# 3718 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 893 "src/frontc/cparser.mly"
                          (RETURN (smooth_expression (fst _2), (*handleLoc*) _1))
# 3727 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 894 "src/frontc/cparser.mly"
                        (BREAK ((*handleLoc*) _1))
# 3735 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 895 "src/frontc/cparser.mly"
                        (CONTINUE ((*handleLoc*) _1))
# 3743 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 897 "src/frontc/cparser.mly"
                   (GOTO (fst _2, (*handleLoc*) _1))
# 3752 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 899 "src/frontc/cparser.mly"
                                 ( COMPGOTO (smooth_expression (fst _3), (*handleLoc*) _1) )
# 3762 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 6 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 5 : Cabs.attribute list) in
    let _3 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 3 : 'asmtemplate) in
    let _5 = (peek_val parser_env 2 : 'asmoutputs) in
    let _7 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 901 "src/frontc/cparser.mly"
                        ( ASM (_2, _4, _5, (*handleLoc*) _1) )
# 3774 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 902 "src/frontc/cparser.mly"
                        ( ASM ([], [fst _1], None, (*handleLoc*)(snd _1)))
# 3781 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.expression list * cabsloc) in
    let _5 = (peek_val parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 904 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _5 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/except in GCC code";
                          TRY_EXCEPT (b, COMMA (fst _4), h, (*handleLoc*) _1) )
# 3796 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 910 "src/frontc/cparser.mly"
                        ( let b, _, _ = _2 in
                          let h, _, _ = _4 in
                          if not !Cprint.msvcMode then 
                            parse_error "try/finally in GCC code";
                          TRY_FINALLY (b, h, (*handleLoc*) _1) )
# 3810 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 916 "src/frontc/cparser.mly"
                                 ( (NOP _2))
# 3818 "src/frontc/cparser.ml"
               : Cabs.statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.expression) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 921 "src/frontc/cparser.mly"
                                 ( FC_EXP _1 )
# 3826 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.definition) in
    Obj.repr(
# 922 "src/frontc/cparser.mly"
                                 ( FC_DECL _1 )
# 3833 "src/frontc/cparser.ml"
               : 'for_clause))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.init_name list) in
    let _3 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 927 "src/frontc/cparser.mly"
                                       ( doDeclaration ((*handleLoc*)(snd _1)) (fst _1) _2 )
# 3842 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 929 "src/frontc/cparser.mly"
                                       ( doDeclaration ((*handleLoc*)(snd _1)) (fst _1) [] )
# 3850 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 932 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 3857 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.init_name) in
    let _3 = (peek_val parser_env 0 : Cabs.init_name list) in
    Obj.repr(
# 933 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 3865 "src/frontc/cparser.ml"
               : Cabs.init_name list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 937 "src/frontc/cparser.mly"
                                        ( (_1, NO_INIT) )
# 3872 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.name) in
    let _3 = (peek_val parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 939 "src/frontc/cparser.mly"
                                        ( (_1, _3) )
# 3880 "src/frontc/cparser.ml"
               : Cabs.init_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 944 "src/frontc/cparser.mly"
                                        ( SpecTypedef :: _2, _1  )
# 3888 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 945 "src/frontc/cparser.mly"
                                        ( SpecStorage EXTERN :: _2, _1 )
# 3896 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 946 "src/frontc/cparser.mly"
                                        ( SpecStorage STATIC :: _2, _1 )
# 3904 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 947 "src/frontc/cparser.mly"
                                        ( SpecStorage AUTO :: _2, _1 )
# 3912 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 948 "src/frontc/cparser.mly"
                                        ( SpecStorage REGISTER :: _2, _1)
# 3920 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 950 "src/frontc/cparser.mly"
                                          ( SpecType (fst _1) :: _2, snd _1 )
# 3928 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 952 "src/frontc/cparser.mly"
                                        ( SpecInline :: _2, _1 )
# 3936 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.spec_elem * cabsloc) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 953 "src/frontc/cparser.mly"
                                        ( (fst _1) :: _2, snd _1 )
# 3944 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'attribute_nocv) in
    let _2 = (peek_val parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 954 "src/frontc/cparser.mly"
                                        ( SpecAttr (fst _1) :: _2, snd _1 )
# 3952 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    Obj.repr(
# 956 "src/frontc/cparser.mly"
                                        ( [ SpecPattern(fst _3) ], _1 )
# 3961 "src/frontc/cparser.ml"
               : spec_elem list * cabsloc))
; (fun parser_env ->
    Obj.repr(
# 961 "src/frontc/cparser.mly"
                                        ( [] )
# 3967 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 962 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 3974 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt))
; (fun parser_env ->
    Obj.repr(
# 969 "src/frontc/cparser.mly"
                                        ( [] )
# 3980 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 970 "src/frontc/cparser.mly"
                                        ( fst _1 )
# 3987 "src/frontc/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 973 "src/frontc/cparser.mly"
                    ( Tvoid, _1)
# 3994 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 974 "src/frontc/cparser.mly"
                    ( Tchar, _1 )
# 4001 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 975 "src/frontc/cparser.mly"
                    ( Tshort, _1 )
# 4008 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 976 "src/frontc/cparser.mly"
                    ( Tint, _1 )
# 4015 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 977 "src/frontc/cparser.mly"
                    ( Tlong, _1 )
# 4022 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 978 "src/frontc/cparser.mly"
                    ( Tint64, _1 )
# 4029 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 979 "src/frontc/cparser.mly"
                    ( Tfloat, _1 )
# 4036 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 980 "src/frontc/cparser.mly"
                    ( Tdouble, _1 )
# 4043 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 981 "src/frontc/cparser.mly"
                    ( Tsigned, _1 )
# 4050 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 982 "src/frontc/cparser.mly"
                    ( Tunsigned, _1 )
# 4057 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 984 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 4065 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : 'just_attributes) in
    let _3 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 986 "src/frontc/cparser.mly"
                                                   ( Tstruct (_3, None,    _2), _1 )
# 4074 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : 'id_or_typename) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 988 "src/frontc/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 4085 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _4 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 990 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 4095 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : 'just_attributes) in
    let _3 = (peek_val parser_env 3 : 'id_or_typename) in
    let _4 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 992 "src/frontc/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 4107 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : 'just_attributes) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 994 "src/frontc/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 4118 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 996 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 4126 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : 'id_or_typename) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 998 "src/frontc/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 4137 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _4 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1000 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 4147 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : 'just_attributes) in
    let _3 = (peek_val parser_env 3 : 'id_or_typename) in
    let _4 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1002 "src/frontc/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 4159 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : 'just_attributes) in
    let _3 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 1 : Cabs.field_group list) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1004 "src/frontc/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 4170 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1006 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 4178 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : 'id_or_typename) in
    let _3 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 2 : Cabs.enum_item list) in
    let _5 = (peek_val parser_env 1 : 'maybecomma) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1008 "src/frontc/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 4190 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 2 : Cabs.enum_item list) in
    let _4 = (peek_val parser_env 1 : 'maybecomma) in
    let _5 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1010 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 4201 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 6 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 5 : 'just_attributes) in
    let _3 = (peek_val parser_env 4 : 'id_or_typename) in
    let _4 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _5 = (peek_val parser_env 2 : Cabs.enum_item list) in
    let _6 = (peek_val parser_env 1 : 'maybecomma) in
    let _7 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1012 "src/frontc/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 4214 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 4 : 'just_attributes) in
    let _3 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 2 : Cabs.enum_item list) in
    let _5 = (peek_val parser_env 1 : 'maybecomma) in
    let _6 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1014 "src/frontc/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 4226 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1015 "src/frontc/cparser.mly"
                    ( Tnamed (fst _1), snd _1 )
# 4233 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1016 "src/frontc/cparser.mly"
                                        ( TtypeofE (fst _3), _1 )
# 4242 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1017 "src/frontc/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 4252 "src/frontc/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun parser_env ->
    Obj.repr(
# 1023 "src/frontc/cparser.mly"
                                         ( [] )
# 4258 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1025 "src/frontc/cparser.mly"
                                         ( (fst _1, 
                                            [(missingFieldDecl, None)]) :: _3 )
# 4268 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1029 "src/frontc/cparser.mly"
                                         ( _2 )
# 4276 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1031 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) 
                                            :: _4 )
# 4287 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'pragma) in
    let _2 = (peek_val parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1034 "src/frontc/cparser.mly"
                                          ( _2 )
# 4295 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1037 "src/frontc/cparser.mly"
                                          ( _3 )
# 4303 "src/frontc/cparser.ml"
               : Cabs.field_group list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1040 "src/frontc/cparser.mly"
                                         ( [_1] )
# 4310 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.name * expression option) in
    let _3 = (peek_val parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1041 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 4318 "src/frontc/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 1044 "src/frontc/cparser.mly"
                                    ( (_1, None) )
# 4325 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.name) in
    let _3 = (peek_val parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1045 "src/frontc/cparser.mly"
                                    ( (_1, Some (fst _3)) )
# 4333 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1046 "src/frontc/cparser.mly"
                                    ( (missingFieldDecl, Some (fst _2)) )
# 4340 "src/frontc/cparser.ml"
               : Cabs.name * expression option))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1050 "src/frontc/cparser.mly"
                  ([_1])
# 4347 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.enum_item list) in
    let _3 = (peek_val parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1051 "src/frontc/cparser.mly"
                                       (_1 @ [_3])
# 4355 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.enum_item list) in
    Obj.repr(
# 1052 "src/frontc/cparser.mly"
                                        ( _1 )
# 4362 "src/frontc/cparser.ml"
               : Cabs.enum_item list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1055 "src/frontc/cparser.mly"
            ((fst _1, NOTHING, snd _1))
# 4369 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1056 "src/frontc/cparser.mly"
                         ((fst _1, fst _3, snd _1))
# 4377 "src/frontc/cparser.ml"
               : Cabs.enum_item))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : attribute list list * cabsloc) in
    let _2 = (peek_val parser_env 1 : string * Cabs.decl_type) in
    let _3 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1062 "src/frontc/cparser.mly"
                                         ( let (n, decl) = _2 in
                                           (n, applyPointer (fst _1) decl, _3, (*(*handleLoc*)*)(snd _1)) )
# 4387 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1070 "src/frontc/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 4394 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.attribute list) in
    let _3 = (peek_val parser_env 1 : Cabs.name) in
    Obj.repr(
# 1073 "src/frontc/cparser.mly"
                                   ( let (n,decl,al,loc) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 4404 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string * Cabs.decl_type) in
    let _3 = (peek_val parser_env 2 : Cabs.attribute list) in
    let _4 = (peek_val parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1077 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, _4)) )
# 4414 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string * Cabs.decl_type) in
    let _3 = (peek_val parser_env 2 : Cabs.attribute list) in
    Obj.repr(
# 1080 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     (n, ARRAY(decl, _3, NOTHING)) )
# 4423 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string * Cabs.decl_type) in
    let _2 = (peek_val parser_env 2 : 'parameter_list_startscope) in
    let _3 = (peek_val parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1083 "src/frontc/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, isva))
                                   )
# 4436 "src/frontc/cparser.ml"
               : string * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1090 "src/frontc/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 4443 "src/frontc/cparser.ml"
               : 'parameter_list_startscope))
; (fun parser_env ->
    Obj.repr(
# 1093 "src/frontc/cparser.mly"
                                   ( ([], false) )
# 4449 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.single_name) in
    let _2 = (peek_val parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1094 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _2 in 
                                     (_1 :: params, isva) 
                                   )
# 4459 "src/frontc/cparser.ml"
               : 'rest_par_list))
; (fun parser_env ->
    Obj.repr(
# 1099 "src/frontc/cparser.mly"
                                        ( ([], false) )
# 4465 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun parser_env ->
    Obj.repr(
# 1100 "src/frontc/cparser.mly"
                                        ( ([], true) )
# 4471 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : Cabs.single_name) in
    let _3 = (peek_val parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1101 "src/frontc/cparser.mly"
                                        ( let (params, isva) = _3 in 
                                          (_2 :: params, isva)
                                        )
# 4481 "src/frontc/cparser.ml"
               : 'rest_par_list1))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 1108 "src/frontc/cparser.mly"
                                          ( (fst _1, _2) )
# 4489 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1109 "src/frontc/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, cabslu)) )
# 4498 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1111 "src/frontc/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], cabslu)) )
# 4505 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1112 "src/frontc/cparser.mly"
                                          ( _2 )
# 4513 "src/frontc/cparser.ml"
               : Cabs.single_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : attribute list list * cabsloc) in
    let _2 = (peek_val parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1117 "src/frontc/cparser.mly"
                                      ( let (n, decl, a) = _2 in
					  (n, applyPointer (fst _1) decl, 
                                           a, snd _1) 
                                      )
# 4524 "src/frontc/cparser.ml"
               : Cabs.name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string * Cabs.decl_type) in
    let _2 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 2 : string list) in
    let _5 = (peek_val parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1126 "src/frontc/cparser.mly"
                                   ( let par_decl, isva = doOldParDecl _3 _5 in
                                     let n, decl = _1 in
                                     (n, PROTO(decl, par_decl, isva), [])
                                   )
# 4537 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.decl_type) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1131 "src/frontc/cparser.mly"
                                   ( let n, decl = _1 in
                                     (n, PROTO(decl, [], false), [])
                                   )
# 4547 "src/frontc/cparser.ml"
               : 'direct_old_proto_decl))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1146 "src/frontc/cparser.mly"
                                               ( [fst _1] )
# 4554 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : string list) in
    Obj.repr(
# 1147 "src/frontc/cparser.mly"
                                               ( let rest = _3 in
                                                 (fst _1 :: rest) )
# 4563 "src/frontc/cparser.ml"
               : string list))
; (fun parser_env ->
    Obj.repr(
# 1152 "src/frontc/cparser.mly"
                                          ( ([], false) )
# 4569 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 2 : 'old_pardef) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1154 "src/frontc/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 4578 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 2 : 'old_pardef) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _4 = (peek_val parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1156 "src/frontc/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva) 
                                          )
# 4590 "src/frontc/cparser.ml"
               : 'old_pardef_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 1162 "src/frontc/cparser.mly"
                                          ( [_1] )
# 4597 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.name) in
    let _3 = (peek_val parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1163 "src/frontc/cparser.mly"
                                          ( _1 :: _3 )
# 4605 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun parser_env ->
    Obj.repr(
# 1164 "src/frontc/cparser.mly"
                                          ( [] )
# 4611 "src/frontc/cparser.ml"
               : 'old_pardef))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.attribute list) in
    let _3 = (peek_val parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1169 "src/frontc/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 4620 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun parser_env ->
    Obj.repr(
# 1172 "src/frontc/cparser.mly"
                                 ( let l = currentLoc () in
                                   ([], l) )
# 4627 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1174 "src/frontc/cparser.mly"
                                 ( _1 )
# 4634 "src/frontc/cparser.ml"
               : attribute list list * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1178 "src/frontc/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then begin
                                   parse_error "attributes in type name";
                                   raise Parsing.Parse_error
                                 end;
                                 (fst _1, d) 
                               )
# 4648 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1185 "src/frontc/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 4655 "src/frontc/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : attribute list list * cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.decl_type) in
    let _3 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1188 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 4664 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1189 "src/frontc/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 4671 "src/frontc/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.attribute list) in
    let _3 = (peek_val parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1196 "src/frontc/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 4682 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1201 "src/frontc/cparser.mly"
                                   ( JUSTBASE )
# 4689 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.decl_type) in
    let _3 = (peek_val parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1204 "src/frontc/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 4697 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.decl_type) in
    let _2 = (peek_val parser_env 2 : 'parameter_list_startscope) in
    let _3 = (peek_val parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1207 "src/frontc/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params, isva)
                                   )
# 4709 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1213 "src/frontc/cparser.mly"
                                    ( _1 )
# 4716 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    Obj.repr(
# 1214 "src/frontc/cparser.mly"
                                    ( JUSTBASE )
# 4722 "src/frontc/cparser.ml"
               : Cabs.decl_type))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (peek_val parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1218 "src/frontc/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by 
                                    * announceFunctionName *)
            doFunctionDef ((*handleLoc*) loc) (trd3 _2) specs decl (fst3 _2)
          )
# 4735 "src/frontc/cparser.ml"
               : Cabs.definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 1228 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 4745 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.name) in
    Obj.repr(
# 1234 "src/frontc/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 4755 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : 'parameter_list_startscope) in
    let _3 = (peek_val parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1239 "src/frontc/cparser.mly"
                           ( let (params, isva) = _3 in
                             let fdec = 
                               (fst _1, PROTO(JUSTBASE, params, isva), [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                           )
# 4771 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 2 : string list) in
    let _5 = (peek_val parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1250 "src/frontc/cparser.mly"
                           ( (* Convert pardecl to new style *)
                             let pardecl, isva = doOldParDecl _3 _5 in
                             (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, pardecl,isva), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec) 
                            )
# 4791 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1263 "src/frontc/cparser.mly"
                           ( (* Make the function declarator *)
                             let fdec = (fst _1,
                                         PROTO(JUSTBASE, [], false), 
                                         [], snd _1) in
                             announceFunctionName fdec;
                             (* Default is int type *)
                             let defSpec = [SpecType Tint] in
                             (snd _1, defSpec, fdec)
                            )
# 4807 "src/frontc/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1276 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_CONST), _1 )
# 4814 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1277 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_VOLATILE), _1 )
# 4821 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1278 "src/frontc/cparser.mly"
                                        ( SpecCV(CV_RESTRICT), _1 )
# 4828 "src/frontc/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun parser_env ->
    Obj.repr(
# 1283 "src/frontc/cparser.mly"
                   ( [])
# 4834 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'attribute) in
    let _2 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1284 "src/frontc/cparser.mly"
                                 ( fst _1 :: _2 )
# 4842 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    Obj.repr(
# 1290 "src/frontc/cparser.mly"
                                        ( [] )
# 4848 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'attribute) in
    let _2 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1291 "src/frontc/cparser.mly"
                                        ( fst _1 :: _2 )
# 4856 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 2 : string * cabsloc) in
    let _5 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1293 "src/frontc/cparser.mly"
                                        ( ("__asm__", 
					   [CONSTANT(CONST_STRING (fst _3))]) :: _5 )
# 4867 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : 'paren_attr_list_ne) in
    Obj.repr(
# 1300 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 4876 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1305 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 4884 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1306 "src/frontc/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 4891 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1308 "src/frontc/cparser.mly"
                                        ( ("__thread",[]), _1 )
# 4898 "src/frontc/cparser.ml"
               : 'attribute_nocv))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1313 "src/frontc/cparser.mly"
                                        ( _1 )
# 4905 "src/frontc/cparser.ml"
               : 'attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1314 "src/frontc/cparser.mly"
                                        ( ("const", []), _1 )
# 4912 "src/frontc/cparser.ml"
               : 'attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1315 "src/frontc/cparser.mly"
                                        ( ("restrict",[]), _1 )
# 4919 "src/frontc/cparser.ml"
               : 'attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1316 "src/frontc/cparser.mly"
                                        ( ("volatile",[]), _1 )
# 4926 "src/frontc/cparser.ml"
               : 'attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : 'paren_attr_list_ne) in
    Obj.repr(
# 1324 "src/frontc/cparser.mly"
                                        ( ("__attribute__", _3) )
# 4935 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1325 "src/frontc/cparser.mly"
                                        ( ("__declspec", _2) )
# 4943 "src/frontc/cparser.ml"
               : 'just_attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1331 "src/frontc/cparser.mly"
                                        ( [_1] )
# 4950 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'just_attribute) in
    let _2 = (peek_val parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1332 "src/frontc/cparser.mly"
                                        ( _1 :: _2 )
# 4958 "src/frontc/cparser.ml"
               : 'just_attributes))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : 'attr) in
    Obj.repr(
# 1337 "src/frontc/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 4966 "src/frontc/cparser.ml"
               : 'pragma))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : 'attr) in
    let _3 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1338 "src/frontc/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 4975 "src/frontc/cparser.ml"
               : 'pragma))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1339 "src/frontc/cparser.mly"
                                        ( PRAGMA (VARIABLE (fst _1), 
                                                  snd _1) )
# 4983 "src/frontc/cparser.ml"
               : 'pragma))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1346 "src/frontc/cparser.mly"
             ( VARIABLE (fst _1) )
# 4990 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1348 "src/frontc/cparser.mly"
                  ( VARIABLE (fst _1) )
# 4997 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : 'attr) in
    Obj.repr(
# 1349 "src/frontc/cparser.mly"
                                        ( _2 )
# 5005 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1350 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), [VARIABLE (fst _2)]) )
# 5013 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1351 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_INT (fst _1)) )
# 5020 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1352 "src/frontc/cparser.mly"
                                         ( CONSTANT(CONST_STRING (fst _1)) )
# 5027 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1356 "src/frontc/cparser.mly"
                                         ( VARIABLE "aconst" )
# 5034 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1357 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 5042 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1359 "src/frontc/cparser.mly"
                                         ( VARIABLE (fst _1 ^ ":" ^ fst _3) )
# 5050 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1360 "src/frontc/cparser.mly"
                                         ( VARIABLE ("default:" ^ fst _3) )
# 5058 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1365 "src/frontc/cparser.mly"
                                         ( VARIABLE ("__noreturn__") )
# 5065 "src/frontc/cparser.ml"
               : 'primary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1369 "src/frontc/cparser.mly"
                                         ( _1 )
# 5072 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1372 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), [VARIABLE ""]) )
# 5080 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string * Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1373 "src/frontc/cparser.mly"
                                         ( CALL(VARIABLE (fst _1), _2) )
# 5088 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_attr) in
    let _3 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1375 "src/frontc/cparser.mly"
                                         (MEMBEROFPTR (_1, _3))
# 5096 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_attr) in
    let _3 = (peek_val parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1376 "src/frontc/cparser.mly"
                                         (MEMBEROF (_1, _3))
# 5104 "src/frontc/cparser.ml"
               : 'postfix_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1383 "src/frontc/cparser.mly"
                                         ( _1 )
# 5111 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1384 "src/frontc/cparser.mly"
                                         (EXPR_SIZEOF (fst _2) )
# 5119 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1386 "src/frontc/cparser.mly"
                           (let b, d = _3 in TYPE_SIZEOF (b, d))
# 5128 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1388 "src/frontc/cparser.mly"
                                         (EXPR_ALIGNOF (fst _2) )
# 5136 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1389 "src/frontc/cparser.mly"
                                         (let b, d = _3 in TYPE_ALIGNOF (b, d))
# 5145 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1390 "src/frontc/cparser.mly"
                                        (UNARY (PLUS, _2))
# 5153 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1391 "src/frontc/cparser.mly"
                                        (UNARY (MINUS, _2))
# 5161 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1392 "src/frontc/cparser.mly"
                            (UNARY (MEMOF, _2))
# 5169 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1394 "src/frontc/cparser.mly"
                                 (UNARY (ADDROF, _2))
# 5177 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1395 "src/frontc/cparser.mly"
                                 (UNARY (NOT, _2))
# 5185 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1396 "src/frontc/cparser.mly"
                                        (UNARY (BNOT, _2))
# 5193 "src/frontc/cparser.ml"
               : 'unary_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1400 "src/frontc/cparser.mly"
                                         ( _1 )
# 5200 "src/frontc/cparser.ml"
               : 'cast_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1404 "src/frontc/cparser.mly"
                                        ( _1 )
# 5207 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_attr) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1405 "src/frontc/cparser.mly"
                                        (BINARY(MUL ,_1 , _3))
# 5216 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_attr) in
    let _3 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1406 "src/frontc/cparser.mly"
                                          (BINARY(DIV ,_1 , _3))
# 5224 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_attr) in
    let _3 = (peek_val parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1407 "src/frontc/cparser.mly"
                                          (BINARY(MOD ,_1 , _3))
# 5232 "src/frontc/cparser.ml"
               : 'multiplicative_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1412 "src/frontc/cparser.mly"
                                        ( _1 )
# 5239 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_attr) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1413 "src/frontc/cparser.mly"
                                            (BINARY(ADD ,_1 , _3))
# 5248 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_attr) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1414 "src/frontc/cparser.mly"
                                            (BINARY(SUB ,_1 , _3))
# 5257 "src/frontc/cparser.ml"
               : 'additive_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1418 "src/frontc/cparser.mly"
                                        ( _1 )
# 5264 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_attr) in
    let _3 = (peek_val parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1419 "src/frontc/cparser.mly"
                                     (BINARY(SHL ,_1 , _3))
# 5272 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_attr) in
    let _3 = (peek_val parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1420 "src/frontc/cparser.mly"
                                     (BINARY(SHR ,_1 , _3))
# 5280 "src/frontc/cparser.ml"
               : 'shift_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1424 "src/frontc/cparser.mly"
                                        ( _1 )
# 5287 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_attr) in
    let _3 = (peek_val parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1425 "src/frontc/cparser.mly"
                                   (BINARY(LT ,_1 , _3))
# 5295 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_attr) in
    let _3 = (peek_val parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1426 "src/frontc/cparser.mly"
                                   (BINARY(GT ,_1 , _3))
# 5303 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_attr) in
    let _3 = (peek_val parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1427 "src/frontc/cparser.mly"
                                      (BINARY(LE ,_1 , _3))
# 5311 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_attr) in
    let _3 = (peek_val parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1428 "src/frontc/cparser.mly"
                                      (BINARY(GE ,_1 , _3))
# 5319 "src/frontc/cparser.ml"
               : 'relational_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1432 "src/frontc/cparser.mly"
                                        ( _1 )
# 5326 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_attr) in
    let _3 = (peek_val parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1433 "src/frontc/cparser.mly"
                                            (BINARY(EQ ,_1 , _3))
# 5334 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_attr) in
    let _3 = (peek_val parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1434 "src/frontc/cparser.mly"
                                            (BINARY(NE ,_1 , _3))
# 5342 "src/frontc/cparser.ml"
               : 'equality_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1439 "src/frontc/cparser.mly"
                                        ( _1 )
# 5349 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_and_attr) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1440 "src/frontc/cparser.mly"
                                       (BINARY(BAND ,_1 , _3))
# 5358 "src/frontc/cparser.ml"
               : 'bitwise_and_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1444 "src/frontc/cparser.mly"
                                           ( _1 )
# 5365 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (peek_val parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1445 "src/frontc/cparser.mly"
                                           (BINARY(XOR ,_1 , _3))
# 5373 "src/frontc/cparser.ml"
               : 'bitwise_xor_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1449 "src/frontc/cparser.mly"
                                          ( _1 )
# 5380 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'bitwise_or_attr) in
    let _3 = (peek_val parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1450 "src/frontc/cparser.mly"
                                          (BINARY(BOR ,_1 , _3))
# 5388 "src/frontc/cparser.ml"
               : 'bitwise_or_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1454 "src/frontc/cparser.mly"
                                                ( _1 )
# 5395 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_and_attr) in
    let _2 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1455 "src/frontc/cparser.mly"
                                             (BINARY(AND ,_1 , _3))
# 5404 "src/frontc/cparser.ml"
               : 'logical_and_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1459 "src/frontc/cparser.mly"
                                               ( _1 )
# 5411 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_or_attr) in
    let _3 = (peek_val parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1460 "src/frontc/cparser.mly"
                                               (BINARY(OR ,_1 , _3))
# 5419 "src/frontc/cparser.ml"
               : 'logical_or_attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1464 "src/frontc/cparser.mly"
                                         ( _1 )
# 5426 "src/frontc/cparser.ml"
               : 'attr))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'attr) in
    Obj.repr(
# 1468 "src/frontc/cparser.mly"
                                         ( [_1] )
# 5433 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'attr) in
    let _3 = (peek_val parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1469 "src/frontc/cparser.mly"
                                         ( _1 :: _3 )
# 5441 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun parser_env ->
    let _3 = (peek_val parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1470 "src/frontc/cparser.mly"
                                         ( _3 )
# 5448 "src/frontc/cparser.ml"
               : 'attr_list_ne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1473 "src/frontc/cparser.mly"
                                         ( _2 )
# 5456 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1474 "src/frontc/cparser.mly"
                                         ( [] )
# 5463 "src/frontc/cparser.ml"
               : 'paren_attr_list_ne))
; (fun parser_env ->
    Obj.repr(
# 1478 "src/frontc/cparser.mly"
                                        ( [] )
# 5469 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1479 "src/frontc/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 5477 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : Cabs.cabsloc) in
    let _2 = (peek_val parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1480 "src/frontc/cparser.mly"
                                        ( ("const", []) :: _2 )
# 5485 "src/frontc/cparser.ml"
               : Cabs.attribute list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1483 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 5492 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'one_string_constant) in
    let _2 = (peek_val parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1484 "src/frontc/cparser.mly"
                                                 ( _1 :: _2 )
# 5500 "src/frontc/cparser.ml"
               : 'asmtemplate))
; (fun parser_env ->
    Obj.repr(
# 1487 "src/frontc/cparser.mly"
                        ( None )
# 5506 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'asmoperands) in
    let _3 = (peek_val parser_env 0 : 'asminputs) in
    Obj.repr(
# 1489 "src/frontc/cparser.mly"
                        ( let (ins, clobs) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs} )
# 5515 "src/frontc/cparser.ml"
               : 'asmoutputs))
; (fun parser_env ->
    Obj.repr(
# 1493 "src/frontc/cparser.mly"
                                        ( [] )
# 5521 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1494 "src/frontc/cparser.mly"
                                        ( List.rev _1 )
# 5528 "src/frontc/cparser.ml"
               : 'asmoperands))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1497 "src/frontc/cparser.mly"
                                        ( [_1] )
# 5535 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'asmoperandsne) in
    let _3 = (peek_val parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1498 "src/frontc/cparser.mly"
                                        ( _3 :: _1 )
# 5543 "src/frontc/cparser.ml"
               : 'asmoperandsne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string * cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    let _3 = (peek_val parser_env 1 : Cabs.expression * cabsloc) in
    Obj.repr(
# 1501 "src/frontc/cparser.mly"
                                                 ( (fst _1, fst _3) )
# 5552 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string * cabsloc) in
    let _2 = (peek_val parser_env 2 : Cabs.cabsloc) in
    Obj.repr(
# 1502 "src/frontc/cparser.mly"
                                                 ( (fst _1, NOTHING ) )
# 5560 "src/frontc/cparser.ml"
               : 'asmoperand))
; (fun parser_env ->
    Obj.repr(
# 1505 "src/frontc/cparser.mly"
                             ( ([], []) )
# 5566 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'asmoperands) in
    let _3 = (peek_val parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1507 "src/frontc/cparser.mly"
                        ( (_2, _3) )
# 5574 "src/frontc/cparser.ml"
               : 'asminputs))
; (fun parser_env ->
    Obj.repr(
# 1510 "src/frontc/cparser.mly"
                                        ( [] )
# 5580 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1511 "src/frontc/cparser.mly"
                                        ( _2 )
# 5587 "src/frontc/cparser.ml"
               : 'asmclobber))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1514 "src/frontc/cparser.mly"
                                                 ( [_1] )
# 5594 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'one_string_constant) in
    let _3 = (peek_val parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1515 "src/frontc/cparser.mly"
                                                 ( _1 :: _3 )
# 5602 "src/frontc/cparser.ml"
               : 'asmcloberlst_ne))
(* Entry interpret *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
|]
let yytables =
  { actions=yyact;
    transl_const=yytransl_const;
    transl_block=yytransl_block;
    lhs=yylhs;
    len=yylen;
    defred=yydefred;
    dgoto=yydgoto;
    sindex=yysindex;
    rindex=yyrindex;
    gindex=yygindex;
    tablesize=yytablesize;
    table=yytable;
    check=yycheck;
    error_function=parse_error;
    names_const=yynames_const;
    names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 1 lexfun lexbuf : Cabs.definition list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 2 lexfun lexbuf : Cabs.definition list)
;;
# 1519 "src/frontc/cparser.mly"



# 5635 "src/frontc/cparser.ml"
